      PROGRAM MULT
      PARAMETER (MXP=120)
C
C        MXP = MAX NUMBER OF PARAMETER FOR ANY MODEL 
C
CCONTROL SEGMENT 'MULT',USLINIT,RANGE ON,TABLES ON
CTITLE '*** Program MULT 12/18/87 ***'
C  Changes: 10/23/91 : Changed max parms to MXP in parameter stmt
C           12/18/87 : Modified input subroutine to accept output
C              filename, and T(i) as free format.
C           7/20/87 : Modified model numbers, changed gof test
C             to match ESTIMATE & BROWNIE
C           7/10/87 : Changed output for full rank BROWNIE & ESTIMATE
C              models to bias corrected
C           4/21/87 : Converted to FORTRAN77, added menu input
C           1/29/86 : IF(MOD.GT.6.)GOTO 240 inserted near start
C                                   of INITL1
C          4/23/86 : Initialize A,B,AY,BY in subr INITL1 to .5
C********************************************************************
C***************************  PROGRAM MULT  ************************
C--------------------------------------------------------------------
C    THIS PROGRAM COMPUTES ESTIMATES OF SURVIVAL,RECOVERY,HARVEST,
C    AND/OR REPORTING RATE USING THE MULTINOMIAL METHODS DESCIBED
C    BY M. CONROY.
C
C     SOURCE PROGRAM: MLTSRC.CONROY.MGB
C     THERE ARE 2 BASIC TYPES OF DATA AND PROBABLITY STRUCTURES
C     CONSIDERED IN THESE MODELS:
C     IN THE 1ST, N(I) BIRDS ARE BANDED IN EACH OF T YEARS AND
C     R(I,J) BIRDS ARE RECOVERED IN EACH OF K YEARS
C
C     N(1)   R(1,1)   R(1,2) .............R(1,K)
C     N(2)            R(2,2) ............ R(2,K)
C      .                 .                 .
C      .                                   .
C     N(T)                     R(T,T).....R(T,K)
C     THE CELL PROBABILITIES CORRESPONDING TO THESE RECOVERIES
C     ARE DENOTED BY PI(I,J) AND ARE PARAMETERIZED BY RECOVERY,
C     SURVIVAL, AND IN SOME CASES BY HARVEST,REPORTING, AND
C     SOLICITATION PROBABILITIES
C     THE 2ND TYPE OF STRUCTURE CONSIDERS ONLY 1ST-YEAR (DIRECT)
C     RECOVERIES, STRATIFIED BY YEARS OR GEOGRAPHIC AREAS, FOR
C     A REWARD-BAND STUDY. HUNTER-REPORTED AND SOLICITED STANDARD
C     RECOVERIES, AND REWARD RECOVERIES, ARE SEPARATELY CONSIDERED
C     FOR EXAMPLE:
C                        HUNTER-REPORTED           SOLICITED
C     STANDARD BANDS
C                      AREA1   AREA2  AREA3   AREA1 AREA2 AREA2
C     YEAR
C      1    N(1) RI(1,1) RI(1,2) RI(1,3) RS(1,1) RS(1,2) RS(1,3)
C      2    N(2) RI(2,1) RI(2,1) RI(2,3) RS(2,1) RS(2,2) RS(2,3)
C      3    N(3) RI(3,1) RI(3,2) RI(3,3) RS(3,1) RS(3,2) RS(3,2)
C
C                 REWARD-BANDED
C      1    N'(1) RI'(1,1) RI'(1,2) RI'(1,2)
C      2    N'(2) RI'(2,1) RI'(2,2) RI'(2,3)
C      3    N'(3) RI'(3,1) RI'(3,2) RI'(3,3)
C
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      DOUBLE PRECISION G(MXP),NV0001(MXP),ROWTOT(30,2)
      INTEGER P,T,N2,OUT(2,30)
      INTEGER NI(30,2),RI(30,30,2)
      REAL XOUT(5,30),CHIPRB
      CHARACTER*8 ADYNG(6),TITLE*72,MSETNM*10,CMODEL*4
      COMMON/B1/RI,NI
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(3),N2(6)
      COMMON/B4/THETA(MXP)
      COMMON /B9/XOUT,IDUM
      DATA ADYNG/'ADULTS','YOUNG ','SPRING','FALL','CONTROL','REWARD'/
C
      MSETNM='ESTIMATE  '
      CMODEL='M1  '
      IDUM=0
C
C                    CALL INPUT MENU ROUTINE
C
    5 CALL INMENU(TITLE,NITER,EPSLON,MSETNM,CMODEL,ROWTOT)
C
      WRITE(1,199)CHAR(12),TITLE,MSETNM,CMODEL
  199 FORMAT(A1,' PROGRAM MULT (12/18/87 VERSION)'/1X,30('-')//1X,A72/
     //1X,25('*')/' * MODEL:',A10,'#',A4,' *'/1X,25('*'))
      IF(IDUM.EQ.0)THEN
C  --------------------   PRINT DEFINITIONS
        CALL PMODL(0)
C -------------------------------------------------
        WRITE(1,62)
   62   FORMAT(/' BANDING AND RECOVERY MATRICES:'/1X,30('-'))
        DO 63 I=1,NAGE
          II=0
          IF(MOD.GE.12.AND.MOD.LE.18)II=1
          IF(MOD.GE.19)II=2
          WRITE(1,FMT='(/40X,A8)')ADYNG(I+II*2)
          WRITE(1,61)
   61     FORMAT(/' BANDS  ',44('-'),' RECOVERIES ',44('-'))
          DO 63 J=1,T
   63       WRITE(1,FMT='(1X,I5,20I5)')NI(J,I),(RI(J,L,I),L=1,K)
        IF(MSETNM(1:1).EQ.'I')WRITE(1,64)(PER(I),I=1,K-1)
   64   FORMAT(/' TIME PERIOD LENGTHS:'/(1X,20F6.3))
      ENDIF
      IF(MSETNM(1:1).EQ.'C')WRITE(1,68)(X(I),I=1,T)
   68 FORMAT(/' COVARIATE VECTOR:'/(10(1X,F10.4)))
C  --------------------   PRINT MODEL DESCRIPTIONS
      CALL PMODL(MOD)
C -------------------------------------------------
      IF(IDUM.LE.0)CALL RMAINR
C---------------------------------------------------------
C        COMPUTE VARIANCE-COVARIANCE MATRIX FOR FULL-RANK MODELS
C------------------------------------------------------------
      IF(MOD.EQ.1.OR.MOD.EQ.6.OR.MOD.EQ.9.OR.MOD.EQ.12.OR.MOD.EQ.19.OR.
     .MOD.EQ.25.OR.MOD.EQ.32.OR.MOD.EQ.37.OR.MOD.EQ.46.OR.MOD.EQ.48)THEN
        CALL FULL1(ROWTOT)
        CALL INITL1
        CALL GRDINF(G)
        CALL MATINV(P,DET)
      ELSE
C-----------------------------------------------------------
C      ITERATIVE PROCEDURE FOR GETTING MLE'S OF PARAMETERS
C------------------------------------------------------------
        CALL INITL1
        WRITE(1,200)(THETA(L),L=1,P)
  200 FORMAT(/' INITIAL VALUES OF PARAMETERS (THETA) -'/
     /(10(1X,F10.7)))
        DO 230 ITER = 1,NITER
           CALL GRDINF(G)
           CALL MATINV(P,DET)
           CALL MMULT (G,NV0001,80,80,1)
           DIST=.0D0
           DO 220 L=1,P
              THETA(L)=THETA(L)+NV0001(L)
              DIST=DIST+NV0001(L)*NV0001(L)
  220         CONTINUE
           PRINT *,'ITERATION ',ITER,', DIST=',DIST
  230      IF(DIST.LT.EPSLON)GO TO 250
        WRITE(1,240)DIST,ITER
  240   FORMAT(/' ESTIMATES NOT CONVERGING... (DISTANCE=',E10.4,
     ,  ' ON ITERATION ',I4,')')
        GO TO 5
  250   WRITE(1,260)DIST,ITER
  260   FORMAT(/' ESTIMATES CONVERGED... (DISTANCE=',E10.4,
     ,    ' ON ITERATION ',I4,')')
      ENDIF
      CALL MEANS(MSETNM,CMODEL,ROWTOT,NI)
      IF(IOUT(2).GT.0)CALL CORR(P)
      CALL CHILIK(CHI2,IDF,XLIK)
      WRITE(1,300)MSETNM,CMODEL,XLIK,CHI2,IDF,CHIPRB(IDF,CHI2)
  300 FORMAT(/' GOODNESS OF FIT TEST FOR MODEL: ',A10,'#',A4/
     //'    LOG-LIKELIHOOD = ',F12.4/4X,'CHI-SQUARE     = ',F12.4/
     /4X,'DEG. OF FREEDOM= ',I7/4X,'PROB           = ',F12.4)
C
  350 IDUM=IDUM+1
      XOUT(1,IDUM)=MOD
      XOUT(2,IDUM)=P
      XOUT(3,IDUM)=CHI2
      XOUT(4,IDUM)=IDF
      XOUT(5,IDUM)=XLIK
      GO TO 5
      END
CCONTROL SEGMENT 'MULT   '
      SUBROUTINE INMENU(TITLE,NITER,EPS,MSETNM,CMODEL,ROW)
      IMPLICIT DOUBLE PRECISION(A-L,N-Z)
      PARAMETER (MXP=120)
      INTEGER MSET,MOD,I,J,K,NB,NR,IOUT,NITER,KK,
     , NAGE,CHOICE,IDUM,P,IMOD,N1,NEWM,RANGE(7),MODSV
      INTEGER NI(30,2),RI(30,30,2)
      REAL XOUT,CHIPRB
      CHARACTER*10 CHMSET(7),MSETNM,TITLE*72,FNAME*40,LMOD*16
      CHARACTER*4 NOYES(0:1),CMOD,CMODEL,TMP*2,ABR(7)*2,FOUT*40
      DIMENSION XOUT(5,30),X(30),PER(30),C(MXP),ROW(30,2)
      COMMON/B1/RI,NI
      COMMON/B2/NB,NR,X,PER
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON /B9/XOUT,IDUM
      DATA CHMSET/'ESTIMATE','COVAR','INTERVAL','BROWNIE','TWO-TIME',
     , 'REW-IND','REW-DIR'/
      DATA NOYES/'NO  ','YES '/,LMOD/'........  ....'/
      DATA ABR/' M',' C','IN',' H','TT','RI','RD'/
      DATA FOUT/'LPT1                                    '/
      DATA RANGE/3,2,3,3,7,13,19/
      IF(IDUM.EQ.0)THEN
      TITLE='***********************************************************
     ,*************'
      MOD=1
      EPS=.1D-10
      NITER=10
      NB=30000
      NR=30000
      CALL CSCREN
      PRINT 1
    1 FORMAT(23X,'  @@    @@  @@    @@  @@        @@@@@@@@ '/
     /       22X,'  @@@  @@@  @@    @@  @@        @@@@@@@@ '/
     /       21X,'  @@@@@@@@  @@    @@  @@           @@    '/
     /       20X,'  @@ @@ @@  @@    @@  @@           @@    '/
     /       19X,'  @@ @@ @@  @@    @@  @@           @@    '/
     /       18X,'  @@    @@  @@    @@  @@           @@    '/
     /       17X,'  @@    @@  @@    @@  @@           @@    '/
     /       16X,'  @@    @@  @@@@@@@@  @@@@@@@@     @@    '/
     /       15X,'  @@    @@   @@@@@@   @@@@@@@@     @@    ')
      DO 2 I=1,30
        PER(I)=.1D1
    2   X(I)=.0D0
      DO 3 I=1,3
    3   IOUT(I)=0
      PRINT 4
    4 FORMAT(/18X,'Program MULT 12/18/87 by M. Conroy & J. Hines'//
     /  '    This program computes estimates of survival and recovery'/
     /  ' rates (or covariate coefficients) using band recovery'/
     /  ' data which is assumed to be distributed as a multinomial.'/
     /  '    This program may be obtained (for free) from:'/
     /  20X,'James E. Hines'/20X,'U.S. Fish & Wildlife Service'/
     /  20X,'Patuxent Wildlife Research Center'/20X,'Laurel, MD 20708'/)
      GO TO 501
      ENDIF
      NEWM=0
    5 CALL CSCREN
      PRINT 10,FOUT,TITLE(1:66),NB,NR
   10 FORMAT(1X,12X,'************** MULT Input Menu ****************
     *'//' 0) Output file:[',A40,']'/' 1) Title:[',A66,']'/
     /' 2) Number yrs of banding, # yrs of recovery:[',I3,',',I3,']')
      MOD=IMOD(MSETNM,CMODEL)
      PRINT 50,MSETNM,CMODEL
   50 FORMAT(' 3) Select model [Model-set:',A10,', model:',A4,']')
      NAGE=2
      IF(INDEX('ESTIM,COVAR,INTER',MSETNM(1:5)).GT.0)NAGE=1
      PRINT *,'4) Input recovery matrix and banding vector(s)...'
      PRINT *,'5) Time interval lengths:'
      PRINT 30,(PER(I),I=1,30)
   30 FORMAT('  [',10(F6.3,',')/(3X,9(F6.3,','),F6.3,']'))
      PRINT *,'6) Covariates vector:'
      PRINT 35,(X(I),I=1,30)
   35 FORMAT('  [',7(E10.4,',')/3X,7(E10.4,',')/3X,7(E10.4,',')/
     , 3X,7(E10.4,',')/3X,E10.4,',',E10.4,']')
      PRINT 40,(NOYES(IOUT(I)),I=1,3),NITER,EPS
   40 FORMAT(' 7) Pgm parms:[Print var-cov=',A3,',corr=',A3,',obs/exp=',
     ,A3,',NITER=',I3,',EPS=',E7.2,']')
      PRINT 45
   45 FORMAT(' 8) Change starting values...'/
     /     ' 9) List models on screen'/' 10) Run MULT for this model'/
     /       ' 11) Contrast parameters'/' 12) Quit MULT'/
     /       /' ** Enter choice (0-12):')
      READ(*,*,ERR=99)CHOICE
      IF(CHOICE.EQ.0)THEN
        PRINT *,'Enter new output filename:'
        READ(*,FMT='(A40)')FOUT
      ELSEIF(CHOICE.EQ.1)THEN
        PRINT *,'Enter title:'
        READ(*,FMT='(A72)',END=5,ERR=500)TITLE
      ELSEIF(CHOICE.EQ.2)THEN
        PRINT *,'Enter # yrs of banding, # yrs recovery (eg 5,5):'
        READ(*,*,END=5,ERR=500)NB,NR
      ELSEIF(CHOICE.EQ.3)THEN
        MOD=  INDEX('ESTIMATECOVAR   INTERVALBROWNIE TWO-TIMEREW-IND REW
     ,-DIR',MSETNM(1:5))
        IF(MOD.EQ.1)THEN
          PRINT 47
   47     FORMAT(' Enter Model-set name:'/' (ESTIMATE,COVAR,INTERVAL,',
     ,     'BROWNIE,TWO-TIME,REW-IND,REW-DIR)'/)
          READ(*,FMT='(A10)',END=5,ERR=500)MSETNM
          MOD=INDEX('ESTIMATECOVAR   INTERVALBROWNIE TWO-TIMEREW-IND REW
     ,-DIR',MSETNM(1:5))
        ENDIF
        IF(MOD.LE.0)GO TO 540
        MOD=(MOD-1)/8 + 1
        IF(MOD.EQ.4)PRINT *,'Enter model (H1,H02, or H01):'
        IF(MOD.NE.4)PRINT 48,ABR(MOD),ABR(MOD),RANGE(MOD)
   48   FORMAT(' Enter model (',A2,'1...',A2,I2,'):')
        MODSV=MOD
        READ(*,FMT='(A4)',END=5,ERR=500)CMODEL
        MOD=IMOD(MSETNM,CMODEL)
        IF(MOD.LE.0)THEN
          IF(MODSV.EQ.4)PRINT 46
   46     FORMAT(/' ** Error: Invalid model number!'/
     /     ' Valid numbers are H1, H02 and H01'/)
          IF(MODSV.NE.4)PRINT 49,ABR(MODSV),ABR(MODSV),RANGE(MODSV)
   49     FORMAT(/' ** Error: Invalid model number!'/
     /' Valid model numbers are ',A2,'1 through ',A2,I2/)
          MSETNM='ESTIMATE'
          CMODEL='M1  '
          GO TO 501
        ENDIF
      ELSEIF(CHOICE.EQ.4)THEN
        IF(NB.GT.30)GO TO 300
        PRINT *,'Enter name of file containing matrices or '
        PRINT *,' "KEYBOARD" for prompted input:'
        READ(*,FMT='(A40)',END=5,ERR=500)FNAME
        IF(FNAME(1:8).EQ.'KEYBOARD')THEN
          DO 56 I=1,NAGE
          PRINT *,'Enter recovery matrix number ',I,':'
          DO 55 J=1,NB
            KK=J
            IF(MOD.GT.5)KK=1
            PRINT *,'Enter recoveries from year ',J,':'
            PRINT *,'      (j=',KK,' to ',NR,'):'
   55       READ(*,*)(RI(J,K,I),K=KK,NR)
          PRINT *,'Enter banding vector:'
   56     READ(*,*)(NI(J,I),J=1,NB)
        ELSE
          OPEN(2,FILE=FNAME,ERR=400,STATUS='OLD')
          DO 59 I=1,NAGE
            DO 58 J=1,NB
              READ(2,FMT='(20I4)')(RI(J,K,I),K=1,NR)
   58         PRINT *,(RI(J,K,I),K=1,NR)
            READ(2,FMT='(16I5)')(NI(J,I),J=1,NB)
   59       PRINT *,(NI(J,I),J=1,NB)
          IF(MSETNM(1:1).EQ.'C'.OR.MSETNM(1:1).EQ.'E')THEN
            READ(2,FMT='(F12.11)',END=61,ERR=61)(X(I),I=1,NB)
          ELSEIF(MSETNM(1:1).EQ.'I')THEN
            READ(2,FMT='(F12.11)',END=61,ERR=61)(PER(I),I=1,NB-1)
          ENDIF
   61   CLOSE(2)
        ENDIF
      ELSEIF(CHOICE.EQ.5)THEN
        IF(NB.GT.30)GO TO 300
        PRINT *,'Enter time interval lengths (eg 1,1,1):'
        READ(*,*,END=5,ERR=500)(PER(I),I=1,NB-1)
      ELSEIF(CHOICE.EQ.6)THEN
        IF(NB.GT.30)GO TO 300
        PRINT *,'Enter covariate vector:'
        READ(*,*,END=5,ERR=500)(X(I),I=1,NB-1)
      ELSEIF(CHOICE.EQ.7)THEN
        PRINT *,'Print variance-covariance matrix(Y/N)?'
        READ(*,FMT='(A1)',END=5,ERR=500)TMP
        IOUT(1)=0
        IF(TMP(1:1).EQ.'Y'.OR.TMP(1:1).EQ.'y')IOUT(1)=1
        PRINT *,'Print correlation matrix(Y/N)?'
        READ(*,FMT='(A1)',END=5,ERR=500)TMP
        IOUT(2)=0
        IF(TMP(1:1).EQ.'Y'.OR.TMP(1:1).EQ.'y')IOUT(2)=1
        PRINT *,'Print observed & expected value matrices(Y/N)?'
        READ(*,FMT='(A1)',END=5,ERR=500)TMP
        IOUT(3)=0
        IF(TMP(1:1).EQ.'Y'.OR.TMP(1:1).EQ.'y')IOUT(3)=1
        PRINT *,'Enter NITER,EPS (0,0 to retain old values):'
        READ(*,*,END=5,ERR=500)N1,X1
        IF(N1.GT.0)NITER=N1
        IF(X1.GT..0D0)EPS=X1
      ELSEIF(CHOICE.EQ.8)THEN
        CALL MENU2(IDUM,NAGE,MSETNM,CMODEL)
      ELSEIF(CHOICE.EQ.9)THEN
        CALL HLPMOD
      ELSEIF(CHOICE.EQ.10)THEN
        LMOD(1:10)=MSETNM
        LMOD(13:16)=CMODEL
        GO TO 540
      ELSEIF(CHOICE.EQ.11)THEN
        IF(IDUM.LT.1)THEN
          PRINT *,' ** Error: You must run a model (choice #10)'
          PRINT *,'           before a z-test can be done!'
          GO TO 501
        ELSE
          CALL ZTEST(ROW,NI,NEWM)
          NEWM=1
        ENDIF
      ELSEIF(CHOICE.EQ.12)THEN
        IF(IDUM.GT.0)CALL SMRIZE(CHMSET,TITLE)
        PRINT *,' *********** Program MULT finished ************'
        STOP
      ELSE
   99   PRINT *,'** Please enter a digit between 1 and 11 ***'
        GO TO 501
      ENDIF
      GO TO 5
  300 PRINT *,' ** Error: Number of years of banding must be'
      PRINT *,'           specified before data can be read!'
      PRINT *,' '
      GO TO 501
  400 PRINT *,' ** Error opening file :',FNAME
      GO TO 501
  500 PRINT *,' ** Input error: pleas try again **'
  501 PRINT *,' **     Hit <RETURN> to continue  **'
      READ(*,FMT='(A2)')TMP
      GO TO 5
  540 IF(MOD.LT.1)THEN
        PRINT 550
  550   FORMAT(' ** Error: Invalid model-set!'/
     /' Valid model-sets are:'/'  ESTIMATE,COVAR,INTERVAL,BROWNIE',
     ,',TWO-TIME,REW-IND, and REW-DIR'/)
        MSETNM='ESTIMATE'
        CMODEL='M1  '
        GO TO 501
      ENDIF
      PRINT *,' ** Running MULT...'
      OPEN(1,FILE=FOUT)
      RETURN
      END
CCONTROL SEGMENT 'MULT   '
      SUBROUTINE SMRIZE(CHMSET,TITLE)
      DOUBLE PRECISION XLLDIF
      INTEGER MODPTR(50),MDIF(7)
      REAL XOUT(5,30),CHIPRB
      CHARACTER*10 CHMSET(7),MSETNM,TITLE*72,CHMNUM(7)*2
      CHARACTER*4 CMOD,CMOD1,H(3)
      COMMON /B9/XOUT,IDUM
      DATA MODPTR,MDIF/3*1,2*2,3*3,3*4,7*5,13*6,19*7,0,3,5,8,11,18,31/
      DATA H/'H1 ','H02','H01'/
      DATA CHMNUM/' M',' C','IN',' H','TT','RI','RD'/
      WRITE(1,199)CHAR(12),TITLE
  199 FORMAT(A1,' PROGRAM MULT (12/18/87 VERSION)'/1X,30('-')//1X,A72/)
      WRITE(1,80)
   80 FORMAT(7X,'GOODNESS OF FIT AND LIKELIHOOD STATISTICS:'/
     /   1X,79('-')/'                 NUMBER OF     CHI      ',
     , 'DEGREES OF             LOG '/
     /              ' M O D E L      PARAMETERS    SQUARE    ',
     , ' FREEDOM    PROB    LIKELIHOOD '/
     / 1X,79('-'))
      DO 82 I=1,IDUM
        J=MODPTR(INT(XOUT(1,I)))
        IF(J.NE.4)THEN
          WRITE(1,84)CHMSET(J),CHMNUM(J),INT(XOUT(1,I))-MDIF(J),
     ,    INT(XOUT(2,I)),XOUT(3,I),INT(XOUT(4,I)),
     ,       CHIPRB(INT(XOUT(4,I)),DBLE(XOUT(3,I))),XOUT(5,I)
        ELSE
          WRITE(1,85)CHMSET(J),H(INT(XOUT(1,I))-MDIF(J)),
     ,    INT(XOUT(2,I)),XOUT(3,I),INT(XOUT(4,I)),
     ,       CHIPRB(INT(XOUT(4,I)),DBLE(XOUT(3,I))),XOUT(5,I)
        ENDIF
   82   CONTINUE
   84 FORMAT(/1X,A8,'#',A2,I2,I10,F13.4,I10,F10.4,F14.4)
   85 FORMAT(/1X,A8,'#',A3,I10,F13.4,I10,F10.4,F14.4)
      IF(IDUM.GT.1)THEN
        IF(IDUM.GT.6)WRITE(1,FMT='(1A1)')CHAR(12)
        WRITE(1,90)
   90   FORMAT(/1X,79('=')//16X,'COMPARISON OF MODELS:'/16X,21('-')/
     ,   /'   M O D E L',8X,'M O D E L',7X,'CHI-SQ     DF      PROB')
        DO 100 I=1,IDUM
          DO 100 J=I+1,IDUM
            IF(I.NE.J)THEN
              XLLDIF=2.*ABS(XOUT(5,I)-XOUT(5,J))
              DFDIF =ABS(XOUT(2,I)-XOUT(2,J))
              PR=CHIPRB(INT(DFDIF),XLLDIF)
              II=MODPTR(INT(XOUT(1,I)))
              JJ=MODPTR(INT(XOUT(1,J)))
              III=INT(XOUT(1,I))-MDIF(II)
              JJJ=INT(XOUT(1,J))-MDIF(JJ)
              IF(II.EQ.4)THEN
                IF(XOUT(2,I).LT.XOUT(2,J))THEN
                  WRITE(1,95)CHMSET(II),H(III),CHMSET(JJ),H(JJJ),
     ,                     XLLDIF,INT(DFDIF),PR
                ELSE
                  WRITE(1,95)CHMSET(JJ),H(JJJ),CHMSET(II),H(III),
     ,                     XLLDIF,INT(DFDIF),PR
                ENDIF
              ELSE
                IF(XOUT(2,I).LT.XOUT(2,J))THEN
                  WRITE(1,96)CHMSET(II),CHMNUM(II),III,CHMSET(JJ),
     ,                     CHMNUM(JJ),JJJ,XLLDIF,INT(DFDIF),PR
                ELSE
                  WRITE(1,96)CHMSET(JJ),CHMNUM(JJ),JJJ,CHMSET(II),
     ,                     CHMNUM(II),III,XLLDIF,INT(DFDIF),PR
                ENDIF
              ENDIF
   95         FORMAT(/1X,A8,'# ',A3,' VS ',A8,'# ',A3,F12.4,I6,F10.4)
   96        FORMAT(/1X,A8,'#',A2,I2,' VS ',A8,'#',A2,I2,F12.4,I6,F10.4)
            ENDIF
  100       CONTINUE
      ENDIF
      RETURN
      END
CCONTROL SEGMENT 'MULT   ',RANGE OFF
      SUBROUTINE MENU2(IDUM,NAGE,MSETNM,CMODEL)
      CHARACTER*10 MSETNM,CMODEL*4,TMP*2
      DOUBLE PRECISION S(30),F(30),SY(30),FY(30),A,B,AY,BY,X(30),
     , L(30),G(30),H(30),S1(30),S2(30),PHI(30),ALFA(30),ALFAY(30)
      COMMON /B5/S,F,SY,FY,L,G,H,S1,S2,PHI,ALFA,ALFAY,A,B,AY,BY
      IF(IDUM.LE.0)THEN
      DO 1 I=1,12*30+4
    1   S(I)=.5D0
      ENDIF
    5 CALL CSCREN
      PRINT 10
   10 FORMAT(1X,15X,10('*'),' MULT starting values menu ',10('*')/)
      IF(MSETNM(1:7).NE.'REW-DIR')THEN
        PRINT 20,(S(I),I=1,30),(F(I),I=1,30)
   20   FORMAT(' 1) S(i) - adult survival rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']'/
     /   ' 2) f(i) - adult recovery rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']')
      IF(NAGE.EQ.2)THEN
          PRINT 30,(SY(I),I=1,30),(FY(I),I=1,30)
   30 FORMAT(' 3) S''(i) - young survival rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']'/
     /   ' 4) f''(i) - young recovery rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']')
C*   / ' 5) A,B,A'',B'' - coefficients for linear relationship S&f'/
C*   / '  [',3(F9.3,','),F9.3,']')
        ELSE
          PRINT 40,A,B
   40     FORMAT(' 5) A,B - Coefficients for linear relationship S&f'/
     / '  [',F9.3,',',F9.3,']')
        ENDIF
      ELSE
        PRINT 50,(L(I),I=1,20),(G(I),I=1,30),(H(I),I=1,30)
   50 FORMAT(' 6) Lambda(i) - reporting rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']'/
     / ' 7) Gamma(i) - solicitation rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']'/
     / ' 8) H(i) - reporting rates'/
     / '  [',10(F6.3,','),2(/3X,9(F6.3,','),F6.3),']')
      ENDIF
      PRINT 55
   55 FORMAT(' 9) Return to main menu'//' ** Choice (1-9) ? ')
      READ(*,*,END=500,ERR=400)ICH
      IF(ICH.LT.1.OR.ICH.GT.9)THEN
  400   PRINT *,'** Please enter a number between 1 and 9 **'
        GO TO 5
      ELSE IF(ICH.EQ.9)THEN
        RETURN
      ELSEIF(ICH.EQ.5)THEN
        PRINT *,'Enter A,B:'
        READ(*,*,END=500,ERR=400)A,B
        GO TO 5
      ELSE
        PRINT *,' Enter N1,N2,(value(i),i=N1,N2):'
        READ(*,*,END=500,ERR=400)N1,N2,(X(I),I=N1,N2)
        DO 60 I=N1,N2
   60     S( (ICH-1)*30+I)=X(I)
        GO TO 5
      ENDIF
  500 PRINT *,'** Input error: please try again **'
      PRINT *,'**    Press <RETURN> to continue   **'
      READ(*,FMT='(A2)')TMP
      GO TO 5
      END
CCONTROL SEGMENT 'MULT   '
      FUNCTION CHIPRB(IDF,CHSQ)
      DOUBLE PRECISION CHSQ
C   FUNCTION COMPUTES THE PROB. OF THE CHI SQUARE VALUE 'CHSQ' WITH
C   'DF' DEGREES OF FREEDOM.
C
C   SUBROUTINES NEEDED:
C        FUNCTION ALGAMA
C
      CHIPRB=1.
      IF(CHSQ .LE. 0.002 .OR. IDF .LT. 1) GO TO 50
      A=FLOAT(IDF)/2.
      X=.5*CHSQ
      TERM=1.
      SUM=0.
      COFN=A
      IF(X.GE.A.AND.X.GE.13.)GO TO 20
C              CONVERGENT SERIES FOR X .LT. A OR .LT. 13.
      FACT=-A
   10 TEMP=SUM
      SUM=SUM+TERM
      COFN=COFN+1.
      TERM=TERM*X/COFN
      IF(SUM-TEMP)40,40,10
C                     ASYMPTOTIC SERIES FOR X .GTE. A AND X .GTE. 13.
   20 CHIPRB=0.
      FACT=X
   30 TEMP=SUM
      SUM=SUM+TERM
      COFN=COFN-1.
      RATIO=COFN/X
      TERM=TERM*RATIO
      IF(SUM.GT.TEMP)GO TO 30
C
   40 ARGMNT=ALOG(SUM)-X+A*ALOG(X)-ALGAMA(A)
      IF(ARGMNT .LT. -175.)GO TO 50
      CHIPRB=CHIPRB+EXP(ARGMNT)/FACT
   50 RETURN
      END
csegment 'MULT'
      FUNCTION ALGAMA(A)
C   FUNCTION COMPUTES THE LOG OF THE GAMMA FUNCTION GIVEN
C   THAT THE ARGUMENT IS AN INTEGER OR A MULTIPLE OF 1/2.
C
      ALGAMA=0.0
      I=INT(A)
      B=FLOAT(I)
      IF(B.NE.A)GO TO 20
      IF(A.LE. 2.0)GO TO 40
      DO 10 J=2,I-1
   10      ALGAMA=ALGAMA+ALOG(FLOAT(J))
      GO TO 40
C                  A IS A MULTIPLE OF 1/2
   20 ALGAMA=0.5723649429
      IF(A.LE. 0.5)GO TO 40
      DO 30 J=1,I*2-1,2
   30      ALGAMA=ALGAMA+ALOG(FLOAT(J)/2.)
   40 RETURN
      END
CCONTROL SEGMENT 'MULT'
      FUNCTION IMOD(MSETNM,CMOD)
      CHARACTER*4 CMOD,MSETNM*10
      INTEGER STRT(8)
      DATA STRT/0,3,5,8,11,18,31,51/
      IMOD=0
      I=INDEX('ESTIMATECOVAR   INTERVALBROWNIE TWO-TIMEREW-IND REW-DIR '
     , ,MSETNM(1:5))
      IF(I.GT.0)THEN
        J=(I-1)/8
        IF(J.LE.1)THEN
          IF(CMOD(2:3).LT.'1 '.OR.CMOD(2:3).GT.'3 ')GO TO 99
          IMOD=ICHAR(CMOD(2:2))-ICHAR('0')+J*3
        ELSEIF(J.EQ.3)THEN
          IF(CMOD(2:3).EQ.'1 ')THEN
            IMOD=9
          ELSEIF(CMOD(2:3).EQ.'01'.OR.CMOD(2:3).EQ.'02')THEN
            IMOD=12-(ICHAR(CMOD(3:3))-ICHAR('0'))
          ENDIF
        ELSE
          IF(CMOD(3:3).GE.'0'.AND.CMOD(3:3).LE.'9')IMOD=
     =      ICHAR(CMOD(3:3))-ICHAR('0')
          IF(CMOD(4:4).GE.'0'.AND.CMOD(4:4).LE.'9')IMOD=
     =      ICHAR(CMOD(4:4))-ICHAR('0')+IMOD*10
          IF(IMOD.NE.0)IMOD=STRT(J+1)+IMOD
        ENDIF
        IF(IMOD.GT.STRT(J+2))IMOD=0
      ENDIF
   99 RETURN
      END
CCONTROL SEGMENT 'INIT1  '
      SUBROUTINE INITL1
C********************************************************************
C      SETS INITIAL VALUES FOR MODELS
C      Depending on model, values are assigned to THETA using
C       subroutine ASGNTH.
C********************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER (MXP=120)
      INTEGER P,T
      DOUBLE PRECISION L
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON/B4/THETA(MXP)
      DIMENSION F(30),S(30),FY(30),S1(30),S2(30),L(30),H(30),G(30),
     & PHI(30),SY(30),AL(30),ALY(30),A(1),B(1)
      COMMON /B5/S,F,SY,FY,L,G,H,S1,S2,PHI,AL,ALY,A,B,AY,BY
C
      NAREAS=K/2
      IF(MOD.EQ.1.OR.MOD.EQ.6)THEN
        CALL ASGNTH(F,T,PHI,T-1,AL,K-T,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.2.OR.MOD.EQ.7)THEN
        CALL ASGNTH(F,K,PHI,-(T-1),F,0,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.3.OR.MOD.EQ.8)THEN
        CALL ASGNTH(F,-K,PHI,-(T-1),F,0,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.4)THEN
        IF(A(1)*B(1).EQ..0D0)CALL STRTVL(T-1,S,F,A,B)
        CALL ASGNTH(F,K,A,1,B,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.5)THEN
        IF(A(1)*B(1).EQ..0D0)CALL STRTVL(T-1,S,X,A,B)
        CALL ASGNTH(F,K,A,1,B,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.9)THEN
        CALL ASGNTH(F,T,S,T-1,AL,K-T,FY,T,SY,T-1,ALY,K-T)
      ELSEIF(MOD.EQ.10)THEN
        CALL ASGNTH(F,K,S,-(T-1),FY,T,SY,-(T-1),F,0,F,0)
      ELSEIF(MOD.EQ.11)THEN
        CALL ASGNTH(F,-K,S,-(T-1),FY,-T,SY,-(T-1),F,0,F,0)
      ELSEIF(MOD.EQ.12)THEN
        CALL ASGNTH(F,T,S1,T,S2,T-1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.13)THEN
        CALL ASGNTH(F,T,S1,T,F,0,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.14)THEN
        CALL ASGNTH(F,T,S1,1,S2,T-1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.15)THEN
        CALL ASGNTH(F,T,S1,T,S2,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.16)THEN
        CALL ASGNTH(F,T,S1,1,S2,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.17)THEN
        CALL ASGNTH(F,T,S1,1,F,0,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.18)THEN
        CALL ASGNTH(F,1,S1,1,S2,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.19)THEN
        CALL ASGNTH(L,K,H,K,S1,T-1,S2,T-1,F,0,F,0)
      ELSEIF(MOD.EQ.20)THEN
        CALL ASGNTH(L,K,H,K,S,T-1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.21)THEN
        CALL ASGNTH(L,1,H,K,S,T-1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.22)THEN
        CALL ASGNTH(L,K,H,K,S,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.23)THEN
        CALL ASGNTH(L,1,H,K,S,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.24)THEN
        CALL ASGNTH(L,1,H,1,S,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.25)THEN
        CALL ASGNTH(L,NAREAS,H,NAREAS,G,NAREAS,S1,T-1,S2,T-1,F,0)
      ELSEIF(MOD.EQ.26)THEN
        CALL ASGNTH(L,NAREAS,H,NAREAS,G,NAREAS,S,T-1,F,0,F,0)
      ELSEIF(MOD.EQ.27)THEN
        CALL ASGNTH(L,1,H,NAREAS,G,NAREAS,S,T-1,F,0,F,0)
      ELSEIF(MOD.EQ.28)THEN
        CALL ASGNTH(L,NAREAS,H,NAREAS,G,NAREAS,S,1,F,0,F,0)
      ELSEIF(MOD.EQ.29)THEN
        CALL ASGNTH(L,1,H,NAREAS,G,NAREAS,S,1,F,0,F,0)
      ELSEIF(MOD.EQ.30)THEN
        CALL ASGNTH(L,1,H,NAREAS,G,1,S,1,F,0,F,0)
      ELSEIF(MOD.EQ.31)THEN
        CALL ASGNTH(L,1,H,1,G,1,S,1,F,0,F,0)
      ELSEIF(MOD.EQ.32)THEN
        CALL ASGNTH(L,T*NAREAS,G,T*NAREAS,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.33)THEN
        CALL ASGNTH(L,T,G,T*NAREAS,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.34)THEN
        CALL ASGNTH(L,NAREAS,G,T*NAREAS,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.35)THEN
        CALL ASGNTH(L,1,G,T*NAREAS,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.36)THEN
        CALL ASGNTH(L,NAREAS,G,NAREAS,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.37)THEN
        CALL ASGNTH(L,NAREAS,G,NAREAS,H,NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.38)THEN
        CALL ASGNTH(L,NAREAS,G,NAREAS,H,T,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.39)THEN
        CALL ASGNTH(L,NAREAS,G,1,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.40)THEN
        CALL ASGNTH(L,1,G,NAREAS,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.41)THEN
        CALL ASGNTH(L,1,G,1,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.42)THEN
        CALL ASGNTH(L,1,G,1,H,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.43)THEN
        CALL ASGNTH(L,T,G,T,H,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.44)THEN
        CALL ASGNTH(L,T,G,1,H,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.45)THEN
        CALL ASGNTH(L,1,G,NAREAS,H,1,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.46)THEN
        CALL ASGNTH(L,T,G,T,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.47)THEN
        CALL ASGNTH(L,1,G,T,H,T*NAREAS,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.48)THEN
        CALL ASGNTH(L,NAREAS,H,NAREAS,F,0,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.49)THEN
        CALL ASGNTH(L,1,H,NAREAS,F,0,F,0,F,0,F,0)
      ELSEIF(MOD.EQ.50)THEN
        CALL ASGNTH(L,1,H,1,F,0,F,0,F,0,F,0)
      ENDIF
  840 RETURN
      END
CCONTROL SEGMENT 'INIT1'
      SUBROUTINE ASGNTH(X1,N1,X2,N2,X3,N3,X4,N4,X5,N5,X6,N6)
      PARAMETER (MXP=120)
      DOUBLE PRECISION X1(30),X2(30),X3(30),X4(30),X5(30),X6(30),TH
      COMMON /B3/NP,MOD,NAGE,IOUT(3),NF(6)
      COMMON /B4/TH(MXP)
C
C     ASSIGNS FHAT,SHAT,... TO PARAMETER VECTOR THETA
C
C       The first N1 values of X1 are assigned to TH, followed by
C       the next N2 values of X2,...
C       If N1 (or N2 or N3...) is < 0 then an average value of X1
C       is used.
C
      IF(N1.LT.0)THEN
        TH(1)=AVG(X1,-N1)
        NF(1)=1
      ELSE
        NF(1)=N1
        DO 10 I=1,N1
   10     TH(I)=X1(I)
      ENDIF
      IF(N2.LT.0)THEN
        NF(2)=NF(1)+1
        TH(NF(1)+1)=AVG(X2,-N2)
      ELSEIF(N2.GT.0)THEN
        NF(2)=NF(1)+N2
        DO 20 I=1,N2
   20     TH(NF(1)+I)=X2(I)
      ELSE
        NF(2)=NF(1)
      ENDIF
      IF(N3.LT.0)THEN
        NF(3)=NF(2)+1
        TH(NF(3))=AVG(X3,-N3)
      ELSEIF(N3.GT.0)THEN
        NF(3)=NF(2)+N3
        DO 30 I=1,N3
   30     TH(NF(2)+I)=X3(I)
      ELSE
        NF(3)=NF(2)
      ENDIF
      IF(N4.LT.0)THEN
        NF(4)=NF(3)+1
        TH(NF(4))=AVG(X4,-N4)
      ELSEIF(N4.GT.0)THEN
        NF(4)=NF(3)+N4
        DO 40 I=1,N4
   40     TH(NF(3)+I)=X4(I)
      ELSE
        NF(4)=NF(3)
      ENDIF
      IF(N5.LT.0)THEN
        NF(5)=NF(4)+1
        TH(NF(5))=AVG(X5,-N5)
      ELSEIF(N5.GT.0)THEN
        NF(5)=NF(4)+N5
        DO 50 I=1,N5
   50     TH(NF(4)+I)=X5(I)
      ELSE
        NF(5)=NF(4)
      ENDIF
      IF(N6.LT.0)THEN
        NF(6)=NF(5)+1
        TH(NF(6))=AVG(X6,-N6)
      ELSEIF(N6.GT.0)THEN
        NF(6)=NF(5)+N6
        DO 60 I=1,N6
   60     TH(NF(5)+I)=X6(I)
      ELSE
        NF(6)=NF(5)
      ENDIF
      NP=NF(6)
      RETURN
      END
CCONTROL SEGMENT 'INIT1'
      FUNCTION AVG(X,N)
      DOUBLE PRECISION X(30)
      AVG=0.
      DO 10 I=1,N
   10   AVG=AVG+X(I)
      AVG=AVG/FLOAT(N)
      RETURN
      END
CCONTROL SEGMENT 'FULL1  '
      SUBROUTINE FULL1(ROW)
C********************************************************************
C    PGM TO SUMMARIZE DATA AND COMPUTE SURV & RECV RATES
C      FOR MODELS 1,6,9,12,19,25 & 32 (FULL RANK MODELS)
C********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      DOUBLE PRECISION ROW(30,2),COL(30,2),BLOCK(30,2),RHO(30,2)
      DOUBLE PRECISION W(30),Y(30),S(30),SY(30)
      INTEGER T,NI(30,2),RI(30,30,2)
      DIMENSION FHAT(30),SHAT(30),FHATY(30),S1HAT(30),
     &S2HAT(30),XLAMHA(30),HHAT(30),GAMHAT(30),PHIHAT(30)
     &,SHATY(30),ALPHA(30),ALPHAY(30)
      COMMON/B1/RI,NI
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/IP,MOD,NAGE,IOUT(9)
      COMMON /B5/SHAT,FHAT,SHATY,FHATY,XLAMHA,GAMHAT,HHAT,S1HAT,
     ,  S2HAT,PHIHAT,ALPHA,ALPHAY,A,B,AY,BY
      NAREAS=K/2
      IF(MOD.EQ.1.OR.MOD.EQ.6)THEN
C ****************************************************
C      MODELS 1 AND 6
C*****************************************************
      DO 10 I=1,K
   10    COL(I,1)=.0D0
      DO 30 I=1,T
         ROW(I,1)=.0D0
         DO 30 J=1,K
            ROW(I,1)=ROW(I,1)+FLOAT(RI(I,J,1))
   30       COL(J,1)=COL(J,1)+FLOAT(RI(I,J,1))
C
      BLOCK(1,1)=ROW(1,1)
      BLOCK(K,1)=COL(K,1)
      RHO(1,1)=ROW(1,1)/FLOAT(NI(1,1))
      FHAT(1)=COL(1,1)/FLOAT(NI(1,1))
      DO 40 I=2,T
         IM1=I-1
         BLOCK(I,1)=ROW(I,1)+BLOCK(I-1,1)-COL(I-1,1)
         RHO(I,1)=ROW(I,1)/FLOAT(NI(I,1))
         FHAT(I)=COL(I,1)/BLOCK(I,1)*RHO(I,1)
         SHAT(IM1)=(RHO(IM1,1)-FHAT(IM1))/RHO(I,1)
   40    PHIHAT(IM1)=SHAT(IM1)**(.1D1/PER(IM1))
      DO 50 I=T+1,K
   50   FHAT(I)=FHAT(T)
   60 WRITE(1,70)
   70 FORMAT(/' INTERMEDIATE STATISTICS -'/
     /'         COLUMN       ROW        BLOCK        ^         ^'/
     /'    I    TOTAL       TOTAL       TOTAL       RHO       PHI'/
     / 2X,62('-'))
      DO 80 I=1,T
   80   WRITE(1,90)I,COL(I,1),ROW(I,1),BLOCK(I,1),RHO(I,1),PHIHAT(I)
   90 FORMAT(1X,I4,F8.0,F13.0,F12.0,2F12.7)
      IF(K.GT.T)THEN
        DO 100 J=1,K-T
          BLOCK(T+J,1)=BLOCK(T+J-1,1)-COL(T+J-1,1)
          ALPHA(J)=ROW(T,1)/FLOAT(NI(T,1))*COL(T+J,1)/BLOCK(T,1)
  100     WRITE(1,110)T+J,COL(T+J,1),BLOCK(T+J,1)
  110   FORMAT(1X,I4,F8.0,13X,F12.0)
      ENDIF
      ELSEIF(MOD.EQ.12)THEN
C******************************************************************
C                  MODEL 12
C***************************************************************
C      COMPUTES SUMMARY STATISTICS AND INITIAL VALUES FOR MODEL
C      12- 2 TIME PERIOD SURVIVAL ANALYSES
C--------------------------------------------------------
      DO 130 I=1,K
         COL(I,1)=.0D0
         ROW(I,1)=.0D0
  130    ROW(I,2)=.0D0
      DO 140 M=1,2
         DO 140 I=1,T
            DO 140 J=1,K
               ROW(I,M)=ROW(I,M)+FLOAT(RI(I,J,M))
  140          COL(J,1)=COL(J,1)+FLOAT(RI(I,J,M))
      BLOCK(1,1)=ROW(1,1)+ROW(1,2)
      BLOCK(K,1)=COL(K,1)
      DO 150 I=2,T
  150  BLOCK(I,1)=ROW(I,1)+ROW(I,2)+BLOCK(I-1,1)-COL(I-1,1)
      DO 160 I=1,T
        ROW(I,2)=ROW(I,2)/FLOAT(NI(I,2))
        S1HAT(I)=ROW(I,1)/FLOAT(NI(I,1))/ROW(I,2)
  160   FHAT(I)=COL(I,1)/BLOCK(I,1)*ROW(I,2)
      DO 170 I=1,T-1
        SHAT(I)=ROW(I,2)*(.1D1-COL(I,1)/BLOCK(I,1))/ROW(I+1,2)
  170   S2HAT(I)=SHAT(I)/S1HAT(I+1)
      ELSEIF(MOD.EQ.19)THEN
C  *****************************************************
C          MODEL 19
C  ******************************************************
      DO 230 M=1,2
        DO 190 J=1,K
          ROW(J,M)=.0D0
  190     COL(J,M)=.0D0
        DO 200 I=1,T
          DO 200 J=1,K
            ROW(I,M)=ROW(I,M)+FLOAT(RI(I,J,M))
  200       COL(J,M)=COL(J,M)+FLOAT(RI(I,J,M))
        DO 210 I=1,T
  210     RHO(I,M)=ROW(I,M)/FLOAT(NI(I,M))
        BLOCK(1,M)=ROW(1,M)
        DO 220 I=2,T
  220     BLOCK(I,M)=ROW(I,M)+BLOCK(I-1,M)-COL(I-1,M)
        BLOCK(K,M)=COL(K,M)
  230   CONTINUE
      DO 240 I=1,T
        HHAT(I)=RHO(I,2)*COL(I,2)/BLOCK(I,2)
  240   XLAMHA(I)=RHO(I,1)*COL(I,1)/BLOCK(I,1)/HHAT(I)
      DO 250 I=1,T-1
        S1HAT(I)=RHO(I,1)*(.1D1-COL(I,1)/BLOCK(I,1))/RHO(I+1,1)
        SHAT(I)=S1HAT(I)
  250   S2HAT(I)=RHO(I,2)*(.1D1-COL(I,2)/BLOCK(I,2))/RHO(I+1,2)
      WRITE(1,260)
  260 FORMAT(/53X,'INTERMEDIATE STATISTICS'/
     /8X,22('-'),' CONTROL ',22('-'),7X,22('-'),' REWARD ',24('-')/8X,
     /   'ROW',7X,'COL',6X,'BLOCK',5X,'RHO',5X,'LAMHAT',5X,'S1HAT',
     ,8X,'ROW',7X,'COL',6X,'BLOCK',5X,'RHO',6X,'HHAT',6X,'S2HAT')
      DO 270 I=1,T
  270    WRITE(1,280)ROW(I,1),COL(I,1),BLOCK(I,1),RHO(I,1),XLAMHA(I),
     ,               S1HAT(I),ROW(I,2),COL(I,2),BLOCK(I,2),RHO(I,2),
     ,               HHAT(I),S2HAT(I)
  280 FORMAT(2(1X,3F10.0,3F10.4))
      ELSEIF(MOD.EQ.25)THEN
C  ********************************************************
C           MODEL 25
C  ********************************************************
      DO 320 M=1,2
        DO 300 I=1,K
          ROW(I,M)=.0D0
  300     COL(I,M)=.0D0
        DO 310 I=1,T
          DO 310 J=1,K
            ROW(I,M)=ROW(I,M)+FLOAT(RI(I,J,M))
  310       COL(J,M)=COL(J,M)+FLOAT(RI(I,J,M))
        BLOCK(1,M)=ROW(1,M)
  320   CONTINUE
      DO 330 I=2,NAREAS
        IM1=I-1
        BLOCK(I,1)=ROW(I,1)+BLOCK(IM1,1)-COL(IM1,1)-COL(NAREAS+IM1,1)
  330   BLOCK(I,2)=ROW(I,2)+BLOCK(IM1,2)-COL(IM1,2)
      WRITE(1,340)
  340 FORMAT(/30X,'INTERMEDIATE STATISTICS'/
     /16X,'CONTROL',28X,'REWARD'/8X,'ROW   COL(HR)  COL(SOL)',5X,
     ,'BLOCK',7X,'ROW',7X,'COL',5X,'BLOCK')
      DO 350 I=1 ,T
  350   WRITE(1,360) ROW(I,1),COL(I,1),COL(I+NAREAS,1),BLOCK(I,1),
     /    ROW(I,2),COL(I,2),BLOCK(I,2)
  360 FORMAT(1X,7F10.0)
C
      DO 370 I=1,T
         ROW(I,1)=ROW(I,1)/FLOAT(NI(I,1))
         ROW(I,2)=ROW(I,2)/FLOAT(NI(I,2))
         FHATH=COL(I,1)/BLOCK(I,1)*ROW(I,1)
         FHATS=COL(NAREAS+I,1)/BLOCK(I,1)*ROW(I,1)
         FHAT(I)=FHATH+FHATS
         HHAT(I)=COL(I,2)/BLOCK(I,2)*ROW(I,2)
         GAMHAT(I)=FHATS/HHAT(I)
  370    XLAMHA(I)=FHATH/HHAT(I)/(.1D1-GAMHAT(I))
      WRITE(1,380)
  380 FORMAT(/'    I',9X,'HHAT      GAMHAT      LAMHAT    ROW(H&S)',
     ,'   ROW(RWD)       S1HAT       S2HAT')
      DO 390 I=1,T-1
         S1HAT(I)=(ROW(I,1)-FHAT(I))/ROW(I+1,1)
         SHAT(I)=S1HAT(I)
         S2HAT(I)=(ROW(I,2)-HHAT(I))/ROW(I+1,2)
  390    WRITE(1,400)I,HHAT(I),GAMHAT(I),XLAMHA(I),ROW(I,1),ROW(I,2),
     ,    S1HAT(I),S2HAT(I)
  400 FORMAT(1X,I5,7F12.4)
      WRITE(1,400)T,HHAT(T),GAMHAT(T),XLAMHA(T),ROW(T,1),ROW(T,2)
      ELSEIF(MOD.EQ.9)THEN
C***********************************************************
C      TWO AGE CLASS, MODEL 9
C************************************************************
      DO 420 I=1,K
        W(I)=.0D0
        Y(I)=.0D0
        S(I)=.0D0
        SY(I)=.0D0
        DO 420 J=1,2
        ROW(I,J)=.0D0
  420   COL(I,J)=.0D0
      DO 430 I=1,T
        ROW(I,1)=.0D0
        ROW(I,2)=.0D0
        DO 430 J=1,K
          ROW(I,1)=ROW(I,1)+FLOAT(RI(I,J,1))
          ROW(I,2)=ROW(I,2)+FLOAT(RI(I,J,2))
          COL(J,1)=COL(J,1)+FLOAT(RI(I,J,1))
  430     COL(J,2)=COL(J,2)+FLOAT(RI(I,J,2))
      BLOCK(1,1)=ROW(1,1)
      BLOCK(1,2)=ROW(1,2)
      DO 440 I=2,T
        BLOCK(I,1)=ROW(I,1)+BLOCK(I-1,1)-COL(I-1,1)
  440   BLOCK(I,2)=ROW(I,2)+BLOCK(I-1,2)-COL(I-1,2)
      DO 450 I=T+1,K
        BLOCK(I,1)=BLOCK(I-1,1)-COL(I-1,1)
  450   BLOCK(I,2)=BLOCK(I-1,2)-COL(I-1,2)
      DO 460 I=1,T
        W(I)=COL(I,1)+COL(I,2)-FLOAT(RI(I,I,2))
  460   Y(I)=BLOCK(I,1)+BLOCK(I,2)-ROW(I,2)
      DO 470 I=1,T
        FHAT(I)=ROW(I,1)/FLOAT(NI(I,1))*(W(I)/Y(I))
  470   FHATY(I)=FLOAT(RI(I,I,2))/FLOAT(NI(I,2))
      DO 480 I=1,T-1
        SHAT(I)=ROW(I,1)/FLOAT(NI(I,1))*(Y(I)-W(I))/Y(I)*
     1   (FLOAT(NI(I+1,1)))/(ROW(I+1,1))
        XXX=FLOAT(RI(I,I,2))
        SHATY(I)=(ROW(I,2)-XXX)/FLOAT(NI(I,2))*(FLOAT(NI(I+1,1))
     1   )/(ROW(I+1,1))
        XX=ROW(I+1,1)/FLOAT(NI(I+1,1))*(FLOAT(NI(I+1,1))+1)
     1   /(ROW(I+1,1)+1)
        S(I)=SHAT(I)*XX
        SY(I)=SHATY(I)*XX
  480   CONTINUE
      DO 490 I=T+1,K
  490   FHAT(I)=FHAT(T)
      IF(K.LE.T)GOTO  510
      DO 500 J=1,K-T
        ALPHA(J)=(COL(T+J,1)+COL(T+J,2))/(BLOCK(T+1,1)+BLOCK(T+1,2))*
     1  ROW(T,1)/NI(T,1)*(Y(T)-W(T))/Y(T)
        X1=FLOAT(RI(T,T,2))
        X2=FLOAT(NI(T,2))
  500   ALPHAY(J)=(ROW(T,2)-X1)/X2*(COL(T+J,1)+COL(T+J,2))/
     1  (BLOCK(T+1,1)+BLOCK(T+1,2))
  510 CONTINUE
      WRITE(1,520)
  520 FORMAT(' INTERMEDIATE STATISTICS:'//27X,'ADULTS',37X,'YOUNG'/
     /' TIME    COL    ROW  BLOCK   W(I)   Y(I)      S(I)    COL    ',
     ,'ROW  BLOCK   S''(I)'/1X,85('-'))
      DO 540 I=1,K
  540 WRITE(1,550)I,INT(COL(I,1)),INT(ROW(I,1)),INT(BLOCK(I,1)),
     , INT(W(I)),INT(Y(I)),S(I),
     , INT(COL(I,2)),INT(ROW(I,2)),INT(BLOCK(I,2)),SY(I)
  550 FORMAT(1X,I4,5I7,F10.4,3I7,F10.4)
      ELSEIF(MOD.EQ.37.OR.MOD.EQ.48)THEN
      NAREAS=K/2
C-------------------------------------
C              MODELS 37 OR 48 (OLD MODELS 1 OR 12)
C-------------------------------------
      DO 600 I=1,NAREAS
         HHAT(I)=DBLE(FLOAT(RI(1,I,2)))/DBLE(FLOAT(NI(1,2)))
         GAMHAT(I)=DBLE(FLOAT(RI(1,I+NAREAS,1)))/DBLE(FLOAT(NI(1,1)))/
     /               HHAT(I)
  600    XLAMHA(I)=DBLE(FLOAT(RI(1,I,1)))/DBLE(FLOAT(NI(1,1)))/
     /                              HHAT(I)/(.1D1-GAMHAT(I))
      P=3*NAREAS
      ELSEIF(MOD.EQ.46)THEN
C-------------------------------------
C              MODEL 46 (OLD MODEL NUMBER 10)
C-------------------------------------
      P=3*T
      DO 620 I=1,T
         HHAT(I)=DBLE(FLOAT(RI(I,1,2)))/DBLE(FLOAT(NI(I,2)))
         GAMHAT(I)=DBLE(FLOAT(RI(I,2,1)))/DBLE(FLOAT(NI(I,1)))/
     /               HHAT(I)
  620    XLAMHA(I)=DBLE(FLOAT(RI(I,1,1)))/DBLE(FLOAT(NI(I,1)))/
     /                                   HHAT(I)/(.1D1-GAMHAT(I))
C-----------------------------------------------
C            MODEL 32 (OLD # 15)
C----------------------------------------------
      ELSEIF(MOD.EQ.32)THEN
      DO 650 I=1,T
        DO 650 J=1,NAREAS
          IJ=(I-1)*NAREAS+J
          HHAT(IJ)=DBLE(FLOAT(RI(I,J,2)))/DBLE(FLOAT(NI(I,2)))
          GAMHAT(IJ)=DBLE(FLOAT(RI(I,J+NAREAS,1)))/DBLE(FLOAT(NI(I,1)))/
     /    HHAT(IJ)
          XLAMHA(IJ)=DBLE(FLOAT(RI(I,J,1)))/DBLE(FLOAT(NI(I,1)))/
     /       HHAT(IJ)/(.1D1-GAMHAT(IJ))
  650     CONTINUE
      ENDIF
      RETURN
      END
CCONTROL SEGMENT 'GRDINF '
C----------------------------------------------------
C       COMPUTES VECTOR OF PARTIAL DERIVATIVES AND
C        INFORMATION MATRIX FOR HYPOTHESIZED LIKELIHOOD
C-----------------------------------------------------
      SUBROUTINE GRDINF(G)
      PARAMETER (MXP=120)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      INTEGER P,T
      INTEGER NI(30,2),RI(30,30,2)
      DOUBLE PRECISION INF(MXP,MXP),G(MXP),DPPL(30,MXP)
      COMMON/B1/RI,NI
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON/B7/PPI(30),DPPI(30)
      COMMON/B8/INF
C
      DO 10 M=1,P
        G(M)=.0D0
        DO 10 L=1,P
   10     INF(L,M)=.0D0
C
      DO 80 I=1,T
        ISTRT=I
        IF(MOD.GT.31) ISTRT=1
        DO 70 IAGE=1,NAGE
          IFIN=K+1
          IF(MOD.GT.31.AND.IAGE.EQ.2)IFIN=K/2+1
          DO 30 L=1,P
            CALL RMAINP(IAGE,I,L)
            DO 20 J=ISTRT,K+1
   20         DPPL(J,L)=DPPI(J)
   30       CONTINUE
C
          DO 60 L=1,P
            DO 50 M=1,P
              SUM2=.0D0
              DO 40 J=ISTRT,IFIN
                PI=PPI(J)
                DPL=DPPL(J,L)
                DPM=DPPL(J,M)
                IF(PI.EQ..0D0.AND.MOD.GT.31)GO TO 40
                IF(PI.EQ..0D0)PI=.1D1
                SUM2=SUM2+(DPL*DPM/PI)*NI(I,IAGE)
                IF(L.EQ.P) G(M)=G(M)+FLOAT(RI(I,J,IAGE))/PI*DPM
   40           CONTINUE
              INF(L,M)=INF(L,M)+SUM2
   50         CONTINUE
   60       CONTINUE
   70   CONTINUE
   80 CONTINUE
      RETURN
      END
CCONTROL SEGMENT 'GRDINF '
      SUBROUTINE RMAINP(IAGE,I,L)
C********************************************************************
C    COMPUTES K+1 COLUMN OF CELL PROBABILITY MATRIX AND DERIVATIVES
C********************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      INTEGER  P,T
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON/B7/PPI(30),DPPI(30)
c      PRINT *,'RMAINP:',IAGE,I,L
      PI=.0D0
      DPI=.0D0
      SUM1=.0D0
      SUM2=.0D0
      ISTRT=I
      IFIN=K
      IF(MOD.GT.31)THEN
        ISTRT=1
        IF(IAGE.EQ.2)IFIN=K/2
      ENDIF
      DO 20 J = ISTRT,IFIN
        CALL RECPRB(IAGE,I,J,L,PIJ,DPIJ)
        PPI(J)=PIJ
        DPPI(J)=DPIJ
        SUM1=SUM1+PIJ
   20   SUM2=SUM2+DPIJ
      PPI(IFIN+1)=.1D1-SUM1
      DPPI(IFIN+1)=-SUM2
      RETURN
      END
CCONTROL SEGMENT 'GRDINF '
      SUBROUTINE RECPRB(IAGE,I,J,L,PI,DPI)
C********************************************************************
C     COMPUTES CELL PROBABILITIES (PI(I,J)) AND DERIVATIVES
C     OF CELL PROBABILITIES (DPI(I,J,L)) FOR GENERAL CANONICAL
C     FORM OF 1 OR 2 AGE-CLASS BAND-RECOVERY MODELS.
C     PARAMETERS OF CANONICAL FORM ARE ADULT RECOVERY RATES
C     F(1),F(2)...F(T), ADULT SURVIVAL RATES S(1)..S(T-1)
C     AND PRODUCTS OF INESTIMABLE RECOVERY AND SURVIVAL RATES
C     ALPHA(J)=F(J)*S(J-1) FOR J=T+1...K RECOVERY YEARS.
C     CORRESPONDING PARAMETERS FOR JUVENILES (AGE-CLASS 2)
C     ARE FY(1)...FY(T),SY(1)...SY(T-1),ALPHAY(T+1)..ALPHAY(K)
C     SPECIFIC MODELS ARE FORMED BY SUBROUTINES MODSP1 (ADULTS)
C     AND MODSP1(YOUNG) WHICH DEFINE THE FUNCTIONAL RELATIONSHIPS
C     BETWEEN THE SPECIFIC MODEL AND THE CANONICAL MODEL.
C     FOR EXAMPLE, WHEN SURVIVAL RATES ARE SPECIFIED TO BE CONSTANT
C     WITH TIME-VARYING RECOVERY RATES, F(1)..F(T) ARE DEFINED
C     BY THETA(1)...THETA(T),S(1)...S(T-1) ARE DEFINED BY
C     THETA(K+1)(CONSTANT S), ALPHA(T+1) IS DEFINED BY THETA(T+1)*
C      THETA(K+1)
C      THE DERIVATIVES OF CELL PROBABILITIES HAVE ALL BEEN
C      EXPANDED BY THE CHAIN RULE, AND ARE EXPRESSED AS
C      THE DERIVATIVE OF A CANONICAL PARAMETER WITH RESPECT TO
C      A SPECIFIED THETA(L). EG.,DERIV F(J) .WR. TO THETA(J)
C      J=1...T WOULD BE 1,DERIV S(I) .WR. THETA(K+1) =1,ETC.
C********************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DOUBLE PRECISION LAMBDA,S(30),S1(30),S2(30),SS(30,2)
      INTEGER P,T
      COMMON/B2/T,K,XCOV(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      PI=.0D0
      DPI=.0D0
      IF(MOD.GT.31)GO TO 480
      IF(NAGE.EQ.1)GO TO 20
      IF(MOD.GE.19.AND.MOD.LE.24)GO TO 330
      IF(MOD.GE.25.AND.MOD.LE.31)GO TO 410
      IF(MOD.GE.12.AND.MOD.LE.18)GO TO 260
   20 IF (IAGE.EQ.2) GO TO 140
      IF (J.LT.I) GO TO 520
      IF (J.GT.I) GO TO 30
      CALL MODSP1(1,I,L,F,D1,DFDTH,D2,D3,D4,1)
      PI=F
      DPI=DFDTH
      GO TO 520
   30  CONTINUE
C-------------------------------------------
C      VECTOR OF ADULT SURVIVAL RATES
C----------------------------------------
      DO 40 II=1,T-1
        CALL MODSP1(1,II,1,D1,X,D3,D4,D5,D6,1)
   40   S(II)=X
C -------------------------------------
C           ADULT RECOVERY RATES
C--------------------------------------
      IF (J.GT.T.AND.J.LT.K+1) GO TO 90
      CALL MODSP1(1,J,L,F,D1,D2,D3,D4,D5,1)
      PI=F
C-------------------------------------
C        RECOVERY PROBABLITIES FOR ADULTS
C-----------------------------------------
      DO 50 M = I,J-1
        PI=PI*S(M)
   50   CONTINUE
C---------------------------------------
C      DERIVATIVES FOR ADULT CELL PROB.
C----------------------------------------
      CALL MODSP1(1,J,L,D1,D2,DFDTH,D3,D4,D5,1)
      DP1=DFDTH
      DO 60 M = I,J-1
        DP1=DP1*S(M)
   60   CONTINUE
      DP2=.0D0
      DO 80 N = I,J-1
        SM=.1D1
        DO 70 M = I,J-1
          IF(M.EQ.N)GO TO 70
          SM=SM*S(M)
   70     CONTINUE
        CALL MODSP1(1,N,L,D1,D2,D3,DSDTH,D4,D5,1)
        DP2=DP2+SM*DSDTH
   80   CONTINUE
      CALL MODSP1(1,J,L,F,D1,D2,D3,D4,D5,1)
      DPI=DP1+DP2*F
      GO TO 520
   90 SM=.1D1
      DO 100 M = I,T-1
  100   SM=SM*S(M)
C---------------------------------------------
C       PROBABILITIES INVOLVING PRODUCTS OF INESTIMATABLE PARAMETERS
C        (F AND S WHEN K > T)
C----------------------------------------------
      CALL MODSP1(1,J,L,D1,D2,D3,D4,ALPHA,D6,1)
      IF (I .LT. T)  PI=SM*ALPHA
      IF (I .EQ. T) PI=ALPHA
      DP1=.0D0
      DO 120 N = I,T-1
        SM=.1D1
        DO 110 M = I,T-1
          IF (M .NE. N) SM=SM*S(M)
  110     IF (M .EQ. N) SM=SM*.1D1
        CALL MODSP1 (1,N,L,D1,D2,D3,DSDTH,D5,D6,1)
  120   DP1=DP1+SM*DSDTH
      CALL MODSP1 (1,J,L,D1,D2,D3,D4,D5,DADTH,1)
      SM=.1D1
      DO 130 M = I,T-1
  130   SM=SM*S(M)
      IF (I .LT. T)  DPI=DADTH*SM+ALPHA*DP1
      IF (I .EQ. T) DPI=DADTH
      GO TO 520
  140 CONTINUE
      IF (J.LT.I) GO TO 520
      DO 150 II=1,T-1
        CALL MODSP1(1,II,1,D1,X,D3,D4,D5,D6,1)
  150   S(II)=X
      IF (J.GT.I.AND.J.LE.T) GO TO 160
      IF (J.GT.T.AND.J.LT.K+1) GO TO 210
C--------------------------------------------------
C      YOUNG RECOVERY RATES
C--------------------------------------------------
      CALL MODSP1(2,I,L,FY,D2,DFYDTH,D4,D5,D6,1)
      PI=FY
      DPI=DFYDTH
      GO TO 520
  160 CONTINUE
      CALL MODSP1(1,J,1,F,D2,D3,D4,D5,D6,1)
      CALL MODSP1(2,I,L,D1,SY,D3,D4,D5,D6,1)
C--------------------------------------------
C       YOUNG CELL PROBABILITIES
C--------------------------------------------
      PI=F*SY
      DO 170 M = I+1,J-1
  170  IF(J.GT. I+1) PI=PI*S(M)
C----------------------------------------------
C        DERIVATIVES OF YNG CELL PROBS.
C----------------------------------------------
      CALL MODSP1(1,J,L,F,D2,DFDTH,D4,D5,D6,1)
      CALL MODSP1(2,I,L,D1,SY,D2,DSYDTH,D5,D6,1)
      DP1=F*DSYDTH+SY*DFDTH
      DP2=.0D0
      DO 190 N = I+1,J-1
        SM=.1D1
      DO 180 M = I+1,J-1
           IF(M.NE.N.AND.J.GT.I+1)SM=SM*S(M)
  180 CONTINUE
      CALL MODSP1(1,N,L,D1,D2,D3,DSDTH,D5,D6,1)
  190 IF (J.GT. I+1) DP2=DP2+SM*DSDTH
      SM=.1D1
      IF(J.GT.I+1)THEN
      DO 200 M = I+1,J-1
  200   SM=SM*S(M)
      ENDIF
      CALL MODSP1(1,J,L,F,D2,D3,D4,D5,D6,1)
      CALL MODSP1(2,I,L,D1,SY,D3,D4,D5,D6,1)
      DPI=F*SY*DP2+SM*DP1
      GO TO 520
  210 CONTINUE
      IF (I.EQ.T) GO TO 250
C-------------------------------------------------
C     PRODUCTS OF INESTIMATIBLE PARAMETERS
C--------------------------------------------------
      CALL MODSP1(1,J,L,D1,D2,D3,D4,ALPHA,D6,1)
      CALL MODSP1(2,I,L,D1,SY,D3,D4,D5,D6,1)
      PI=ALPHA*SY
      SM=.1D1
      DO 220 M = I+1,T-1
  220   IF(T.GT.I+1)SM=SM*S(M)
      PI=PI*SM
      CALL MODSP1(1,J,L,D1,D2,D3,D4,ALPHA,DALDTH,1)
      CALL MODSP1(2,I,L,D1,SY,D3,DSYDTH,D5,D6,1)
      DP1=SM*(ALPHA*DSYDTH+DALDTH*SY)
      DP2=.0D0
      DO 240 N = I+1,T-1
        SM=.1D1
        DO 230 M = I+1,T-1
          IF (M.NE.N.AND.T.GT.I+1) SM=SM*S(M)
  230     CONTINUE
        CALL MODSP1(1,N,L,D1,D2,D3,DSDTH,D5,D6,1)
  240   IF (T .GT. I+1) DP2=DP2+SM*DSDTH
      DPI=DP1+ALPHA*SY*DP2
      GO TO 520
  250 CONTINUE
      CALL MODSP1(2,J,L,D1,D2,D3,D4,ALPHAY,DLYDTH,1)
      PI=ALPHAY
      DPI=DLYDTH
      GO TO 520
  260 CONTINUE
C**********************************************************
C TWO TIME-PERIOD SURVIVAL ANALYSES (MODEL-SET=TWO-TIME,MODELS 1-7)
C*******************************************************
      DO 270 II=1,T
        CALL MODSP1(1,II,1,D1,SS1,D2,D3,D4,D5,1)
        CALL MODSP1(2,II,1,D1,SS2,D2,D3,D4,D5,1)
        IF(II.EQ.T)GO TO 270
        S2(II)=SS2
  270   S1(II)=SS1
C                 TWO TIME-PERIOD TRIANGULAR DATA
      IPER=IAGE
      IF (J .LT. I) GO TO 520
      IF (J.GT.I.AND.J.LE.T) GO TO 280
      CALL MODSP1(1,I,L,F,D2,DF,DS1,D3,D4,1)
      PI=F
      DPI=DF
      IF(IPER.EQ.2)GO TO 520
      DPI=DS1*PI+S1(I)*DF
      PI=PI*S1(I)
      GO TO 520
  280 CONTINUE
      CALL MODSP1(1,J,1,F,D1,D2,D3,D4,D5,1)
      PI=F
      DO 290 M=I,J-1
        S(M)=S2(M)*S1(M+1)
  290   PI=PI*S(M)
      CALL MODSP1(1,J,L,D1,D2,DF,D3,D4,D5,1)
      DP1=DF
      DO 300 M=I,J-1
  300   DP1=DP1*S(M)
      DP2=.0D0
      DO 320 N=I,J-1
        SM=.1D1
        DO 310 M=I,J-1
          IF (M.EQ.N)GO TO 310
          SM=SM*S(M)
  310     CONTINUE
        CALL MODSP1(2,N,L,D1,D2,D3,DS2,D4,D5,1)
        CALL MODSP1(1,N+1,L,D1,D2,D3,DS1,D4,D5,1)
        DSDTH=.0D0
        DSDTH=S1(N+1)*DS2+S2(N)*DS1
  320   DP2=DP2+SM*DSDTH
      CALL MODSP1(1,J,1,F,D2,D3,D4,D5,D6,1)
      DPI=DP1+DP2*F
      IF(IPER.EQ.2) GO TO 520
      CALL MODSP1(1,I,L,D1,D2,D3,DS1,D4,D5,1)
      DPI=S1(I)*DPI+DS1*PI
      PI=PI*S1(I)
      GO TO 520
  330 CONTINUE
C**************************************************************
C     REWARD AND CONTROL BAND SURVIVAL ANALYSIS
C   DIRECT AND INDIRECT RECOVERIES FOR DATA STRUCTURE
C      WHERE HUNTER REPORTS ONLY ARE CONSIDERED
C      MODEL-SET REW-IND, MODELS 1-7
C*****************************************************************
      IF (J.LT.I) GO TO 520
      DO 340 IIAGE=1,2
        DO 340 II=1,T-1
          CALL MODSP1(IIAGE,II,1,D1,X,D3,D4,D5,D6,1)
  340     SS(II,IIAGE)=X
      IF (J.GT.I.AND.J.LE.T) GO TO 350
      CALL MODSP1(IAGE,I,L,F,D2,DF,D4,D5,D6,1)
      PI=F
      DPI=DF
      GO TO 400
  350 CONTINUE
      CALL MODSP1(IAGE,J,1,F,D2,D3,D4,D5,D6,1)
      PI=F
      DO 360 M = I,J-1
  360   PI=PI*SS(M,IAGE)
      CALL MODSP1(IAGE,J,L,D1,D2,DF,D4,D5,D6,1)
      DP1=DF
      DO 370 M = I,J-1
  370   DP1=DP1*SS(M,IAGE)
      DP2=.0D0
      DO 390 N = I,J-1
        SM=.1D1
        DO 380 M = I,J-1
          IF (M.EQ.N) GO TO 380
          SM=SM*SS(M,IAGE)
  380     CONTINUE
        CALL MODSP1(IAGE,N,L,D1,D2,D3,DSDTH,D5,D6,1)
  390   DP2=DP2+SM*DSDTH
      CALL MODSP1(IAGE,J,1,F,D2,D3,D4,D5,D6,1)
      DPI=DP1+DP2*F
  400 GO TO 520
  410 CONTINUE
C*******************************************************************
C      REWARD BAND (DIRECT AND INDIRECT  RECOVERIES)
C         WHERE SOLICITED RECOVERIES ARE CONSIDERED SEPARATELY
C       MODEL-SET REW-IND, MODELS 8-13
C******************************************************************
      KK=K/2
      JJ=J
      IF(J.GT.KK.AND.IAGE.EQ.2)GO TO 520
      IF(J.GT.KK)JJ=J-KK
      IF(JJ.LT.I)GO TO 520
      IF (JJ.GT.I.AND.JJ.LE.T) GO TO 420
      CALL MODSP1(IAGE,I,L,F,D2,DFDTH,D3,D4,D5,J)
      PI=F
      DPI=DFDTH
      GO TO 520
  420 CONTINUE
      DO 430 II=1,T-1
        DO 430 IIAGE=1,2
          CALL MODSP1(IIAGE,II,1,D1,X,D2,D3,D4,D5,1)
  430     SS(II,IIAGE)=X
      CALL MODSP1(IAGE,JJ,1,F,D2,D3,D4,D5,D6,J)
      PI=.0D0
      DPI=.0D0
      PI=F
      DO 440 M = I,JJ-1
        PI=PI*SS(M,IAGE)
  440   CONTINUE
      CALL MODSP1(IAGE,JJ,L,D1,D2,DFDTH,D4,D5,D6,J)
      DP1=DFDTH
      DO 450 M = I,JJ-1
        DP1=DP1*SS(M,IAGE)
  450   CONTINUE
      DP2=.0D0
      DO 470 N=I,JJ-1
        SM=.1D1
        DO 460 M = I,JJ-1
          IF(M.NE.N)SM=SM*SS(M,IAGE)
  460     CONTINUE
        CALL MODSP1(IAGE,N,L,D1,D2,D3,DSDTH,D4,D5,1)
  470   DP2=DP2+SM*DSDTH
      CALL MODSP1(IAGE,JJ,L,F,D2,D3,D4,D5,D6,J)
      DPI=DP1+DP2*F
      GO TO 520
C********************************************************************
C         MODEL-SET REW-DIR, MODELS 1-19
C     REWARD BAND ANALYSIS, DIRECT RECOVERIES
C*****************************************************************
  480 NAREAS=K/2
C@@@@@@@@@      IF(IAGE.EQ.1.AND.J.NE.K+1)  GO TO 1150
C@@@@@@@@@      IF(IAGE.EQ.2.AND.J.NE.K/2+1) GO TO 1150
C@@@@@@@@@      GO TO 1300
  490 CONTINUE
      IF (IAGE .EQ.2) GO TO 510
      IF(J-NAREAS .GT. 0) GO TO 500
      CALL MODSP2(I,J,L,LAMBDA,GAMMA,HARV,DLAM,DGAM,DHARV)
      PI=LAMBDA*(.1D1-GAMMA)*HARV
      DPI=DLAM*(.1D1-GAMMA)*HARV+LAMBDA*(DHARV*(.1D1-GAMMA)-HARV*DGAM)
      GO TO 520
  500 CONTINUE
      JJ=J-NAREAS
      CALL MODSP2(I,JJ,L,D1,GAMMA,HARV,D4,DGAM,DHARV)
      PI=GAMMA*HARV
      DPI=GAMMA*DHARV+DGAM*HARV
      GO TO 520
  510 CONTINUE
      IF(J-NAREAS .GT. 0) GO TO 520
      CALL MODSP2(I,J,L,D1,D2,HARV,D4,D5,DHARV)
      PI=HARV
      DPI=DHARV
  520 RETURN
      END
CCONTROL SEGMENT 'MODSP2 '
      SUBROUTINE MODSP2(I,J,L,LAMBDA,GAMMA,HARV,DLAM,DGAM,DHARV)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      PARAMETER (MXP=120)
      INTEGER P,T
      DOUBLE PRECISION LAMBDA
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON/B4/THETA(MXP)
C--------------------------------------------------------
C          PARAMETER SPECIFICATION FOR ALL MODELS IN
C          MODEL SET 'REW-DIR'
C--------------------------------------------------------
      NAREAS=K/2
      LAMBDA=.0D0
      GAMMA=.0D0
      HARV=.0D0
      DLAM=.0D0
      DGAM=.0D0
      DHARV=.0D0
      IF(MOD.EQ.36)THEN
C------------------------------------------------------
C                     MODEL 36 (OLD #0)
C------------------------------------------------------
      LAMBDA=THETA(J)
      GAMMA=THETA(J+NAREAS)
      IJ=(I-1)*NAREAS+J
      IJK=IJ+2*NAREAS
      HARV=THETA(IJK)
      P=T*NAREAS+K
      IF(L.EQ.J) DLAM=.1D1
      IF(L .EQ.J+NAREAS) DGAM=.1D1
      IF(L.EQ.IJK) DHARV=.1D1
      ELSEIF(MOD.EQ.37)THEN
C------------------------------------------------------
C                     MODEL 37 (OLD # 1)
C------------------------------------------------------
      LAMBDA=THETA(J)
      GAMMA=THETA(J+NAREAS)
      HARV=THETA(2*NAREAS+J)
      P=3*NAREAS
      IF(L.EQ.J) DLAM=.1D1
      IF(L.EQ.J+NAREAS) DGAM=.1D1
      IF(L.EQ.2*NAREAS+J) DHARV=.1D1
      ELSEIF(MOD.EQ.38)THEN
C------------------------------------------------------
C                     MODEL 38 (OLD # 2)
C------------------------------------------------------
      LAMBDA=THETA(J)
      JN=J+NAREAS
      GAMMA=THETA(JN)
      IJK=2*NAREAS+I
      HARV=THETA(IJK)
      P=2*NAREAS+T
      IF(L.EQ.J) DLAM=.1D1
      IF(L.EQ.JN) DGAM=.1D1
      IF(L.EQ.IJK) DHARV=.1D1
      ELSEIF(MOD.EQ.39)THEN
C------------------------------------------------------
C                     MODEL 39 (OLD # 3)
C------------------------------------------------------
      LAMBDA=THETA(J)
      N1=NAREAS+1
      GAMMA=THETA(N1)
      IJ=(I-1)*NAREAS+J
      IJK=IJ+N1
      HARV=THETA(IJK)
      P=N1+NAREAS*T
      IF(L.EQ.J) DLAM=.1D1
      IF(L.EQ.N1) DGAM=.1D1
      IF(L.EQ.IJK) DHARV=.1D1
      ELSEIF(MOD.EQ.40)THEN
C------------------------------------------------------
C                     MODEL 40 (OLD # 4)
C------------------------------------------------------
      LAMBDA=THETA(1)
      J1=J+1
      GAMMA=THETA(J1)
      IJ=(I-1)*NAREAS+J
      IJK=1+NAREAS+IJ
      HARV=THETA(IJK)
      P=1+NAREAS+NAREAS*T
      IF(L.EQ.1) DLAM=.1D1
      IF (L.EQ. J1) DGAM=.1D1
      IF (L.EQ.IJK) DHARV=.1D1
      ELSEIF(MOD.EQ.41)THEN
C------------------------------------------------------
C                     MODEL 41 (OLD # 5)
C------------------------------------------------------
      LAMBDA=THETA(1)
      GAMMA=THETA(2)
      IJ=(I-1)*NAREAS+J
      IJK=IJ+2
      HARV=THETA(IJK)
      P=2+NAREAS*T
      IF(L.EQ.1) DLAM=.1D1
      IF (L.EQ.2) DGAM=.1D1
      IF(L.EQ.IJK) DHARV=.1D1
      ELSEIF(MOD.EQ.42)THEN
C------------------------------------------------------
C                     MODEL 42 (OLD # 6)
C------------------------------------------------------
      LAMBDA=THETA(1)
      GAMMA=THETA(2)
      HARV=THETA(3)
      P=3
      IF (L.EQ.1) DLAM=.1D1
      IF(L.EQ.2) DGAM=.1D1
      IF(L.EQ.3) DHARV=.1D1
      ELSEIF(MOD.EQ.43)THEN
C------------------------------------------------------
C                     MODEL 43 (OLD # 7)
C------------------------------------------------------
      P=2*NAREAS+1
      LAMBDA=THETA(J)
      GAMMA=THETA(NAREAS+J)
      HARV=THETA(P)
      IF(L.EQ.J)DLAM=.1D1
      IF(L.EQ.NAREAS+J)DGAM=.1D1
      IF(L.EQ.P)DHARV=.1D1
      ELSEIF(MOD.EQ.44)THEN
C------------------------------------------------------
C                     MODEL 44 (OLD # 8)
C------------------------------------------------------
      LAMBDA=THETA(J)
      GAMMA=THETA(NAREAS+1)
      P=2+NAREAS
      HARV=THETA(P)
      IF(L.EQ.J)DLAM=.1D1
      IF(L.EQ.NAREAS+1)DGAM=.1D1
      IF(L.EQ.P)DHARV=.1D1
      ELSEIF(MOD.EQ.45)THEN
C------------------------------------------------------
C                     MODEL 45 (OLD # 9)
C------------------------------------------------------
      P=2+NAREAS
      LAMBDA=THETA(1)
      GAMMA=THETA(J+1)
      HARV=THETA(P)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.J+1)DGAM=.1D1
      IF(L.EQ.P)DHARV=.1D1
      ELSEIF(MOD.EQ.46)THEN
C------------------------------------------------------
C                     MODEL 46 (OLD # 10)
C------------------------------------------------------
      P=T*2+NAREAS*T
      IJ=(I-1)*NAREAS+J
      LAMBDA=THETA(I)
      GAMMA=THETA(T+I)
      HARV=THETA(2*T+IJ)
      IF(L.EQ.I)DLAM=.1D1
      IF(L.EQ.T+I)DGAM=.1D1
      IF(L.EQ.2*T+IJ)DHARV=.1D1
      ELSEIF(MOD.EQ.47)THEN
C------------------------------------------------------
C                     MODEL 47 (OLD # 11)
C------------------------------------------------------
      P=1+T+NAREAS*T
      IJ=(I-1)*NAREAS+J
      LAMBDA=THETA(1)
      GAMMA=THETA(I+1)
      HARV=THETA(T+1+IJ)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.I+1)DGAM=.1D1
      IF(L.EQ.T+1+IJ)DHARV=.1D1
      ELSEIF(MOD.EQ.48)THEN
C------------------------------------------------------
C                     MODEL 48 (OLD # 12)
C------------------------------------------------------
      P=2*NAREAS
      LAMBDA=THETA(J)
      HARV=THETA(NAREAS+J)
      IF(L.EQ.J)DLAM=.1D1
      IF(L.EQ.NAREAS+J) DHARV=.1D1
      ELSEIF(MOD.EQ.49)THEN
C------------------------------------------------------
C                     MODEL 49 (OLD # 13)
C------------------------------------------------------
      P=NAREAS+1
      LAMBDA=THETA(1)
      HARV=THETA(J+1)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.J+1) DHARV=.1D1
      ELSEIF(MOD.EQ.50)THEN
C------------------------------------------------------
C                     MODEL 50 (OLD # 14)
C------------------------------------------------------
      P=2
      LAMBDA=THETA(1)
      HARV=THETA(2)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.2)DHARV=.1D1
      ELSEIF(MOD.EQ.32)THEN
C----------------------------------
C            MODEL 32 (OLD # 15)
C-------------------------------------
      P=T*NAREAS*3
      IJ=(I-1)*NAREAS+J
      LAMBDA=THETA(IJ)
      GAMMA=THETA(IJ+T*NAREAS)
      HARV=THETA(IJ+2*T*NAREAS)
      IF(L.EQ.IJ)DLAM=.1D1
      IF(L.EQ.IJ+T*NAREAS)DGAM=.1D1
      IF(L.EQ.IJ+2*NAREAS*T)DHARV=.1D1
      ELSEIF(MOD.EQ.33)THEN
C-----------------------------------------
C             MODEL 33 (OLD # 16)
C------------------------------------------
      P=2*T*NAREAS+T
      LAMBDA=THETA(I)
      IJ=(I-1)*NAREAS+J
      GAMMA=THETA(IJ+T)
      HARV=THETA(IJ+T+T*NAREAS)
      IF(L.EQ.I)DLAM=.1D1
      IF(L.EQ.IJ+T)DGAM=.1D1
      IF(L.EQ.IJ+T+T*NAREAS)DHARV=.1D1
      ELSEIF(MOD.EQ.34)THEN
C---------------------------------------------
C               MODEL 34 (OLD # 17)
C-------------------------------------------
      P=2*T*NAREAS+NAREAS
      LAMBDA=THETA(J)
      IJ=(I-1)*NAREAS+J
      GAMMA=THETA(IJ+NAREAS)
      HARV=THETA(IJ+NAREAS+T*NAREAS)
      IF(L.EQ.J)DLAM=.1D1
      IF(L.EQ.IJ+NAREAS)DGAM=.1D1
      IF(L.EQ.IJ+NAREAS+T*NAREAS)DHARV=.1D1
      ELSEIF(MOD.EQ.35)THEN
C----------------------------------------------
C              MODEL 35 (OLD # 18)
C-------------------------------------------
      P=2*T*NAREAS+1
      LAMBDA=THETA(1)
      IJ=(I-1)*NAREAS+J
      GAMMA=THETA(IJ+1)
      HARV=THETA(IJ+1+T*NAREAS)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.IJ+1)DGAM=.1D1
      IF(L.EQ.IJ+1+T*NAREAS)DHARV=.1D1
      ENDIF
      RETURN
      END
CCONTROL SEGMENT 'MATINV '
      SUBROUTINE MATINV (M,DET)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER (MXP=120)
C----------------------------------------------------------
C     INVERSE AND DETERMINANT OF A BY THE GAUSS-JORDAN METHOD.
C     M IS THE ORDER OF THE SQUARE MATRIX, A.
C     A-INVERSE REPLACES A.
C     DETERMINANT OF A IS PLACED IN DET.
C     COOLEY AND LOHNES (1971:63)
C-----------------------------------------------------------
      DIMENSION A(MXP,MXP),IPVT(MXP),PVT(MXP),IND(MXP,2)
      COMMON/B8/A
      DET=.1D1
      DO 10 J=1,M
   10 IPVT(J)=0
      DO 100 I=1,M
C        SEARCH FOR THE PIVOT ELEMENT
         AMAX=.0D0
           DO 40 J=1,M
              IF(IPVT(J).EQ.1)GO TO 40
           DO 30 K=1,M
              IF(IPVT(K)-1)20,30,130
   20         IF(DABS(AMAX).GE.DABS(A(J,K)))GO TO 30
                     IROW=J
              ICOL=K
              AMAX=A(J,K)
   30      CONTINUE
   40   CONTINUE
         IPVT(ICOL)=IPVT(ICOL)+1
C        INTERCHANGE THE ROWS TO PUT THE PIVOT ELEMENT ON THE DIAGONAL
         IF(IROW.EQ.ICOL)GO TO 60
         DET=-DET
           DO 50 L=1,M
              SWAP=A(IROW,L)
              A(IROW,L)=A(ICOL,L)
   50      A(ICOL,L)=SWAP
   60    IND(I,1)=IROW
         IND(I,2)=ICOL
         PVT(I)=A(ICOL,ICOL)
C        DIVIDE THE PIVOT ROW BY THE PIVOT ELEMENT
         A(ICOL,ICOL)=.1D1
           DO 70 L=1,M
             A(ICOL,L)=A(ICOL,L)/PVT(I)
   70      CONTINUE
C       REDUCE THE NON-PIVOT ROWS
      DO 100 L1=1,M
          IF(L1.EQ.ICOL)GO TO 90
         SWAP=A(L1,ICOL)
         A(L1,ICOL)=.0D0
         IF(SWAP.LT..1D-30.AND.SWAP.GT.-.1D-30)SWAP=.0D0
           DO 80 L=1,M
              A(L1,L)=A(L1,L)-A(ICOL,L)*SWAP
   80      CONTINUE
   90  CONTINUE
  100 CONTINUE
C     INTERCHANGE THE COLUMNS
           DO 120 I=1,M
              L=M+1-I
              IF(IND(L,1).EQ.IND(L,2))GO TO 120
              IROW=IND(L,1)
              ICOL=IND(L,2)
                DO 110 K=1,M
                   SWAP=A(K,IROW)
                   A(K,IROW)=A(K,ICOL)
                   A(K,ICOL)=SWAP
  110           CONTINUE
  120      CONTINUE
  130 CONTINUE
      RETURN
      END
CCONTROL SEGMENT 'MMULT  '
      SUBROUTINE MMULT(B,C,IRA,ICA,ICB)
      PARAMETER (MXP=120)
C***********************************************
C   MATRIX PRODUCT SUBPROGRAM
C***********************************************
      DOUBLE PRECISION A(MXP,MXP),B(MXP),C(MXP)
      COMMON/B8/A
      DO 10 I=1,IRA
         DO 10 J=1,ICB
            C(I)=.0D0
            DO 10 K=1,ICA
   10          C(I)=C(I)+A(I,K)*B(K)
      RETURN
      END
CCONTROL SEGMENT 'RMAINR '
      SUBROUTINE RMAINR
C**************************************************
C      COMPUTES K+1 TH COLUMN OF RECOVERY MATRIX
C**************************************************
      LOGICAL M2
      DOUBLE PRECISION X,PER
      INTEGER P,T,SUM
      INTEGER NI(30,2),RI(30,30,2)
      COMMON/B1/RI,NI
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      K1=K+1
      K2=K/2+1
      M2=(MOD.GT.31)
   10 DO 40 I = 1,T
         ISTRT=I
         IF(M2)ISTRT=1
         DO 30 IAGE = 1,NAGE
            SUM=0
            DO 20 J = ISTRT,K
   20          SUM=SUM+RI(I,J,IAGE)
   30       RI(I,K+1,IAGE)=NI(I,IAGE)-SUM
   40    IF(M2)RI(I,K2,2)=RI(I,K1,2)
      RETURN
      END
CCONTROL SEGMENT 'CORRMEAN'
      SUBROUTINE CORR(P)
C********************************************************************
C       CORR COMPUTES & PRINTS THE CORRELATION MATRIX FROM THE
C       INFORMATION MATRIX.
C********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      PARAMETER (MXP=120)
      DOUBLE PRECISION INF(MXP,MXP),COR(MXP)
      COMMON/B8/INF
      INTEGER P,T
      WRITE(1,10)
   10 FORMAT(/' CORRELATION MATRIX -')
      DO 40 L=1,P
        DO 30 M=1,P
          X=INF(L,L)*INF(M,M)
          IF(X.LT..0D0)THEN
            COR(M)=-INF(L,M)/DSQRT(-X)
          ELSE
            COR(M)=INF(L,M)/DSQRT(INF(L,L)*INF(M,M))
          ENDIF
   30     CONTINUE
   40   WRITE(1,50)L,(COR(M),M=L,P)
   50 FORMAT(/1X,I2,(10F12.8))
      RETURN
      END
CCONTROL SEGMENT 'MEANS  ',CODE_OFFSETS ON
      SUBROUTINE MEANS(MSET,CMOD,R,N)
C********************************************************************
C  *****  SUBROUTINE MEANS COMPUTES MEAN AND STANDARD DEVIATIONS OF
C         SELECTED SUB-SETS OF THE THETA VECTOR.
C
C          NOTE:VARIANCES ARE COMPUTED DIFFERENTLY FOR THE
C               SET OF MODELS 'REW-DIR'.
C          ALSO:ESTIMATE & BROWNIE FULL-RANK MODEL ESTIMATES
C               ARE BIAS CORRECTED.
C********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      PARAMETER (MXP=120)
      DOUBLE PRECISION INF(MXP,MXP),R(30,2),BTH(MXP)
      INTEGER N(30,2)
      CHARACTER*12 PARM(50),MSET*10,PRM*2,CMOD*4
      COMMON/B3/NP,MOD,NAGE,IOUT(3),N2(6)
      COMMON/B4/THETA(MXP)
      COMMON/B8/INF
      DATA PARM/3*'F S a ',2*'F a b ',3*'F Q a ','F S a F''S''a''',
     , 2*'F S F''S''',
     , 7*'F Q G ',6*'L H S S''',7*'L H G S S''',16*'L G H ',3*'L H '/
      WRITE(1,50)MSET,CMOD
   50 FORMAT(/' FINAL PARAMETER VALUES FOR MODEL ',A10,'#',A4/
     / / 24X,'STD.ERROR           95 %'/
     /   '    I PARM(I) THETA(I)   THETA(I)   CONFIDENCE INTERVAL'/
     / 1X,55('-'))
      M1=1
      DO 100 I=1,6
        M2=N2(I)
        IF(M2.GE.M1)THEN
          XMEAN=.0D0
          VAR=.0D0
          J=(I-1)*2+1
          PRM=PARM(MOD)(J:J+1)
          DO 60 K=M1,M2
            BTH(K)=THETA(K)
            STD=INF(K,K)
            IF(STD.GT..0D0)STD=DSQRT(STD)
            COV=.0D0
            IF(K.NE.M1)COV=INF(K-1,K)
            IF( ((MOD.EQ.1.OR.MOD.EQ.9).AND.I.EQ.2).OR.
     .         (MOD.EQ.9.AND.I.EQ.5) )THEN
              KK=K-M1+2
              BTH(K)=BTH(K)/
     /        FLOAT(N(KK,1))*R(KK,1) * FLOAT(N(KK,1)+1)/(R(KK,1)+.1D1)
              IF(THETA(K).NE..0D0)THEN
                STD=STD*BTH(K)/THETA(K)
                IF(K.NE.M1.AND.THETA(K-1).NE..0D0)COV=COV*BTH(K)*
     *            BTH(K-1)/THETA(K)/THETA(K-1)
              ENDIF
            ENDIF
            XMEAN=XMEAN+BTH(K)
            IF(MOD.GT.31)THEN
              DO 55 L=M1,M2
   55            VAR=VAR+INF(L,K)
            ELSE
              VAR=VAR+STD*STD+.2D1*COV
            ENDIF
            WRITE(1,57)K,PRM,K-M1+1,BTH(K),STD,BTH(K)-1.96*STD,
     ,       BTH(K)+1.96*STD
   57       FORMAT(1X,I4,1X,A2,'(',I2,')',F10.4,F11.4,F10.4,' - ',F9.4)
   60       CONTINUE
          DF=FLOAT(M2-M1+1)
          XMEAN=XMEAN/DF
          VAR=VAR/(DF*DF)
          STDM=DSQRT(VAR)
          WRITE(1,75)XMEAN,STDM,XMEAN-1.96*STDM,
     ,                                XMEAN+1.96*STDM
   75     FORMAT(1X,55('-')/' MEAN',7X,F10.4,F11.4,F10.4,' - ',F9.4/
     /           1X,55('-')/)
        ENDIF
  100   M1=M2+1
      IF(IOUT(1).GT.0)THEN
        WRITE(1,110)
  110   FORMAT(/' VARIANCE-COVARIANCE MATRIX -')
        DO 120 L = 1,NP
  120     WRITE(1,130)L,(INF(L,M),M=L,NP)
  130   FORMAT(/1X,I2,(10F12.8))
      ENDIF
      RETURN
      END
CCONTROL SEGMENT 'CHILIK '
      SUBROUTINE CHILIK(CHI2,IDF,XLIK)
C********************************************************************
C      THIS SUBROUTINE COMPUTES THE CHI-SQUARE VALUE FOR THE
C      GOODNESS OF FIT TEST, AND THE LOG-LIKELIHOOD VALUE FOR
C      THE MODEL BEING USED.
C********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INTEGER P,T,NI(30,2),RI(30,30,2)
      CHARACTER*10 MSET,CMOD*4
      DIMENSION EXP(30,30,2),POOL(30,30,2)
      COMMON/B1/RI,NI
      COMMON/B2/T,K,XCOV(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON/B7/PPI(30),DPPI(30)
      XLIK=.0D0
      DO 10 L=1,2
        DO 10 J=1,30
          DO 10 I=1,30
            EXP(I,J,L)=.0D0
            POOL(I,J,L)=.0D0
   10       CONTINUE
      ISTRT=1
      IFIN=K+1
      DO 30 IAGE = 1,NAGE
         IF(IAGE.EQ.2.AND.MOD.GT.31)IFIN=K/2+1
         DO 30 I = 1,T
            CALL RMAINP(IAGE,I,1)
            IF(MOD.LE.31)ISTRT=I
            DO 30 J = ISTRT,IFIN
               X=PPI(J)
               POOL(I,J,IAGE)=RI(I,J,IAGE)
               EXP(I,J,IAGE)=NI(I,IAGE)*X
               IF(X.LE..0D0)X=.1D1
   30          XLIK=XLIK+(RI(I,J,IAGE))*DLOG(X)
      CHI2=.0D0
      IDF=NAGE*( (T*T+T)/2+T*(K-T) )
      IF(MOD.GT.31)IDF=T*K*3/2
      IDF=IDF-P
      DO 70 IAGE=1,NAGE
         DO 70 I = 1,T
           IFIN=K
           ISTRT=I
           IF(MOD.GT.31)THEN
             IFIN=K+1
             ISTRT=1
             IF(IAGE.EQ.2)IFIN=K/2+1
           ENDIF
           IF(ISTRT.LT.IFIN)THEN
             DO 60 L=IFIN-1,ISTRT,-1
               IF(EXP(I,L,IAGE).LT.2.OR.EXP(I,IFIN,IAGE).LT.2)THEN
                 EXP(I,IFIN,IAGE)=EXP(I,IFIN,IAGE)+EXP(I,L,IAGE)
                 EXP(I,L,IAGE)=.0D0
                 POOL(I,IFIN,IAGE)=POOL(I,IFIN,IAGE)+POOL(I,L,IAGE)
                 POOL(I,L,IAGE)=.0D0
                 IDF=IDF-1
               ENDIF
               X=EXP(I,L,IAGE)
               Y=POOL(I,L,IAGE)
               IF(X.NE..0D0)CHI2=CHI2+(X-Y)*(X-Y)/X
   60          CONTINUE
           ENDIF
           X=EXP(I,IFIN,IAGE)
           Y=POOL(I,IFIN,IAGE)
           IF(X.NE..0D0)CHI2=CHI2+(X-Y)*(X-Y)/X
   70      CONTINUE
      IF(IOUT(3).LE.0)GOTO  160
      WRITE(1,80)
   80 FORMAT(/' ADULT OBSERVED AND EXPECTED VALUES AFTER POOLING -'/
     / '  --------   OBSERVED   ---------')
      DO 90 I=1,T
   90    WRITE(1,100)I,(POOL(I,J,1),J=1,K)
  100 FORMAT(1X,I2,F10.1,30F6.1)
      WRITE(1,110)
  110 FORMAT(/'  --------   EXPECTED   ---------')
      DO 120 I=1,T
  120    WRITE(1,100)I,(EXP(I,J,1),J=1,K)
      WRITE(1,122)
  122 FORMAT(/' -------- CHI SQUARE VALUES --------')
      DO 124 I=1,T
  124   WRITE(1,100)I,((POOL(I,J,1)-EXP(I,J,1))**2/DMAX1(.1D1,
     ,    EXP(I,J,1)),J=1,K)
      IF (NAGE .EQ.1) GO TO 160
      WRITE(1,130)
  130 FORMAT(/' YOUNG OBSERVED AND EXPECTED VALUES AFTER POOLING -'/
     / '  --------   OBSERVED   ---------')
      IFIN=K
      IF(MOD.GT.31)IFIN=K/2+1
      DO 140 I=1,T
  140    WRITE(1,100)I,(POOL(I,J,2),J=1,IFIN)
      WRITE(1,110)
      DO 150 I=1,T
  150    WRITE(1,100)I,(EXP(I,J,2),J=1,IFIN)
      WRITE(1,122)
      DO 154 I=1,T
  154   WRITE(1,100)I,((POOL(I,J,2)-EXP(I,J,2))**2/DMAX1(.1D1,
     ,    EXP(I,J,2)),J=1,IFIN)
  160 RETURN
      END
CCONTROL SEGMENT 'ZTEST',CODE_OFFSETS ON
      SUBROUTINE ZTEST(R,N,NEWM)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      PARAMETER (MXP=120)
      DOUBLE PRECISION INF(MXP,MXP),C(MXP),R(30,2),BIAS(MXP)
      INTEGER P,T,ISUB(MXP),N(30,2)
      CHARACTER*12 PARM(50),MSET*10,CMOD*4,PRM*2,PRM2(MXP)*2,TMP*1
      COMMON/B3/P,MOD,NAGE,IOUT(3),N2(6)
      COMMON/B4/THETA(MXP)
      COMMON/B8/INF
      DATA PARM/3*'F S a ',2*'F a b ',3*'F Q a ','F S a F''S''a''',
     , 2*'F S F''S''',
     , 7*'F Q G ',6*'L H S S''',7*'L H G S S''',16*'L G H ',3*'L H '/
      Z=.0D0
      SUM=.0D0
      VAR=.0D0
      CALL CSCREN
      PRINT 9
      PRINT 10
      PRINT 11
      WRITE(1,9)
    9 FORMAT(/' Contrast test:')
      IF(NEWM.EQ.0)THEN
      WRITE(1,10)
   10 FORMAT(/' This test compares parameter estimates ',
     1'using the following equation:'/
     2/10X,'                SUM( C(I) * THETA(I))'/
     3 10X,'    Z =    --------------------------------'/
     4 10X,'           SQRT(SUM(SUM(C(I)*C(J)*V(I,J))))'/
     5/ ' testing the null hypothesis:'/
     6/10X,' H0: C(1)*THETA(1)+C(2)*THETA(2)+...C(NP)*THETA(NP)=0.'/
     7/' For example, a test of HO:THETA(1)=2THETA(2) ',
     8/' where NP=5 would be expressed as:')
      WRITE(1,11)
   11 FORMAT(/'    H0:THETA(1) - 2*THETA(2) = 0, ie.',
     2' C(1)=1, C(2)=-2, C(3)=C(4)=C(5)=0.'/
     3/' Under the null hypothesis Z should be NORMAL(0,1).'/)
      ENDIF
      PRM=PARM(MOD)(1:2)
      J=1
      L=1
      K=1
      DO 200 I=1,50
        PRM2(I)='  '
        ISUB(I)=0
        C(I)=.0D0
        BIAS(I)=.0D0
        IF(I.LE.N2(6))THEN
          BIAS(I)=THETA(I)
  190     IF(I.GT.N2(J))THEN
            J=J+1
            K=K+2
            L=1
            PRM=PARM(MOD)(K:K+1)
            GO TO 190
          ENDIF
          IF( ((MOD.EQ.1.OR.MOD.EQ.9).AND.J.EQ.2).OR.
     .      (MOD.EQ.9.AND.J.EQ.5))BIAS(I)=BIAS(I)/
     /      FLOAT(N(L+1,1))*R(L+1,1)*FLOAT(N(L+1,1)+1)/(R(L+1,1)+.1D1)
          PRM2(I)=PRM
          ISUB(I)=L
          L=L+1
        ENDIF
  200   CONTINUE
      PRINT *,' <<Hit return to continue>>'
      READ (*,FMT='(A1)')TMP
  210 CALL CSCREN
      PRINT 220
  220 FORMAT(3('  Num   Parm   Value  Coef'))
      DO 230 I=1,17
        IF(I.LT.17)THEN
          PRINT 235,I,PRM2(I),ISUB(I),BIAS(I),C(I),
     ,      I+17,PRM2(I+17),ISUB(I+17),BIAS(I+17),C(I+17),
     ,      I+2*17,PRM2(I+2*17),ISUB(I+2*17),
     ,     BIAS(I+2*17),C(I+2*17)
        ELSE
          PRINT 235,I,PRM2(I),ISUB(I),BIAS(I),C(I),
     ,      I+17,PRM2(I+17),ISUB(I+17),BIAS(I+17),C(I+17)
        ENDIF
  230   CONTINUE
  235 FORMAT(3(I5,1X,A2,'(',I2,')',F8.4,F6.1))
      PRINT *,' '
      PRINT *,'Enter number of coef to change, or 0 to compute Z:'
      READ *,I
      IF(I.GT.0)THEN
        PRINT *,'Coefficient?'
        READ *,C(I)
        GO TO 210
      ENDIF
      WRITE(1,12)(C(I),I=1,P)
   12 FORMAT(' PARAMETER COEFICIENTS = '/(20(1X,F5.2)))
      DO 20 I=1,P
        SUM=SUM+C(I)*BIAS(I)
          DO 20 J=1,P
   20       VAR=VAR+C(I)*C(J)*INF(I,J)*BIAS(I)*BIAS(J)/THETA(I)/THETA(J)
      IF(VAR.GT..0D0)Z=SUM/DSQRT(VAR)
      WRITE(1,50)Z,.2D1*ZPROB(-DABS(Z))
      PRINT 50,Z,.2D1*ZPROB(-DABS(Z))
      PRINT *,' <<Hit return to continue>>'
      READ (*,FMT='(A1)')TMP
   50 FORMAT(' Z = ',F8.4,'  2-TAIL PROB = ',F8.4)
      RETURN
      END
CCONTROL SEGMENT 'ZTEST'
      FUNCTION ZPROB(ZVAL)
      IMPLICIT DOUBLE PRECISION (A-Z)
C  FUNCTION ZPROB COMPUTES THE PROBABILITY OF A Z VALUE LESS THAN OR
C   EQUAL TO THE INPUT VALUE FOR A STANDARD NORMAL DISTRIBUTION.
C    (I.E. P(Z<=Z)  )
C   THIS PROGRAM WAS CONVERTED FROM THE TEXAS INSTRUMENTS APPLIED
C    STATISTICS MODULE PROGRAM(#19).
C
      ZPROB=0.0
      IF(ZVAL.LT.-5.0)GO TO 10
      ZPROB=1.0
      IF(ZVAL.GT.5.0)GO TO 10
      A=.1D1/DSQRT(DEXP(ZVAL*ZVAL)*6.283185307)
      B=1./(DABS(ZVAL)*0.2316419+1.)
      C=B*B
      D=C*B
      E=D*B
      F=E*B
      TEMP=.31938153D0 * B - .3565637822D0 * C + .1781477937D1 * D -
     -   .1821255978D1 * E + .1330274429D1 * F
      ZPROB=A*TEMP
      IF(ZVAL.GE. .0D0)ZPROB=.1D1-ZPROB
   10 RETURN
      END
CCONTROL SEGMENT 'GRDINF'
      SUBROUTINE MODSP1(IAGE,I,L,F,S,DF,DS,AL,DAL,J)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      PARAMETER (MXP=120)
      DOUBLE PRECISION Y(30)
      INTEGER P,T,Z,ZZ
      COMMON/B2/T,K,X(30),PER(30)
      COMMON/B3/P,MOD,NAGE,IOUT(9)
      COMMON/B4/THETA(MXP)
      F=.0D0
      DF=.0D0
      DS=.0D0
       AL=.0D0
       DAL=.0D0
      IF(NAGE.EQ.2)GO TO 250
      IF(MOD.GT.8)GO TO 250
   10 GO TO (190,210,230,60,120,190,210,230),MOD
C----------------------------------------------------------------------
C                      COVAR-MODEL 1 (MOD=4)
C      PARAMETER SPECIFICATION FOR MODEL IN WHICH SURVIVAL RATES
C      ARE HYPOTHESIZED TO BE A LINEAR FUNCTION OF RECOVERY RATES
C      SO THAT S(I)=A+B*F(I). PARAMETERS OF THIS MODEL ARE F(I),
C      A, AND B. THIS MAY BE A REASONABLE MODEL WHEN TOTAL ANNUAL
C      SURVIVAL RATES ARE THOUGHT TO BE NEGATIVELY RELATED TO
C      HARVEST RATES, I.E.,HUNTING MORTALITY IS ADDITIVE RATHER
C      THAN COMPENSATORY.
C----------------------------------------------------------------------
   60 CONTINUE
      F=THETA(I)
      A=THETA(K+1)
      B=THETA(K+2)
      S=A+B*F
      IF (L .EQ. I) DF=.1D1
      IF (L .EQ. I ) DS=B
      IF (L.EQ.K+1)DS=.1D1
      IF (L.EQ.K+2)DS=THETA(I)
      IF(I.LE.T .OR.I.GE.K+1)GO TO 670
      IF (K.EQ.T)GOTO  670
      DO 70 M=T,K-1
   70 Y(M)=A+B*THETA(M)
      AL=THETA(I)
      DO 80 M=T,I-1
   80 AL=AL*Y(M)
      DP1=DF
      DO 90 M=T,I-1
   90 DP1=DP1*Y(M)
      DP2=.0D0
      DO 110 N=T,I-1
      YM=.1D1
      DO 100 M=T,I-1
      IF(M.EQ.N)GOTO  100
  100 YM=YM*Y(M)
      DY=.0D0
      IF(L.EQ.K+1)DY=.1D1
      IF(L.EQ.K+2)DY=THETA(N)
      IF(L.EQ.N)DY=B
      DP2=DP2+YM*DY
  110 CONTINUE
      DAL=DP1+DP2*F
      GO TO 670
C----------------------------------------------------------------------
C                      COVAR-MODEL 2   (MOD=5)
C      PARAMETERIZATION OF MODEL WHERE SURVIVAL RATES
C      ARE A LINEAR FUNCTION OF A COVARIATE X(I)
C      IE., S(I)=A+B*X(I)
C----------------------------------------------------------------------
  120 F=THETA(I)
      A=THETA(K+1)
      B=THETA(K+2)
      S=A+B*X(I)
      IF(L.EQ.I)DF=.1D1
      IF(L.EQ.K+1) DS=.1D1
      IF(L.EQ.K+2)DS=X(I)
      IF(I.LE.T.OR.I.GE.K+1)GO TO 670
      IF (K.EQ.T)GOTO  670
      DO 130 M=T,K-1
  130 Y(M)=A+B*X(M)
      AL=THETA(I)
      DO 140 M=T,I-1
  140 AL=AL*Y(M)
      DP1=DF
      DO 150 M=T,I-1
  150 DP1=DP1*Y(M)
      DP2=.0D0
      DO 170 N=T,I-1
      YM=.1D1
      DO 160 M=T,I-1
      IF(M.EQ.N)GOTO  160
  160 YM=YM*Y(M)
      DY=.0D0
      IF(L.EQ.K+1)DY=.1D1
      IF(L.EQ.K+2)DY=X(N)
      DP2=DP2+YM*DY
  170 CONTINUE
      DAL=DP1+DP2*F
      GO TO 670
C----------------------------------------------------------------------
C        (MOD=1 & 6)              MODEL ESTIMATE:M1
C      PARAMETER SPECIFICATION FOR TIME-SPECIFIC F AND S
C      THIS IS EQIVALENT TO MODEL M1 OF BROWNIE ET AL
C     AND INTERVAL-MODEL 1 : VARIABLE TIME PERIOD BAND RECOVERY MODEL
C----------------------------------------------------------------------
  190 PHI=.0D0
      DSDP=.0D0
      F=THETA(I)
      IF(L.EQ.I)DF=.1D1
      IF(I.LT.T)PHI=THETA(I+T)
      IF(I.GE.T)GO TO 200
      S=PHI**PER(I)
      IF(L.EQ.I+T)DS=PER(I)*PHI**(PER(I)-.1D1)
  200 IF(I.LE.T .OR.I.GE.K+1)GO TO 670
      AL=THETA(I+T-1)
      IF(L.EQ.I+T-1)DAL=.1D1
      GO TO 670
C----------------------------------------------------------------------
C   (MOD=2 & 7)          ESTIMATE-MODEL 2
C      PARAMETER SPECIFICATION FOR TIME-SPEFIC F AND CONSTANT S
C      THIS IS EQUIVALENT TO MODEL M2 OF BROWNIE ET AL
C    AND INTERVAL-MODEL 2: VARIABLE TIME-PERIOD MODEL
C----------------------------------------------------------------------
  210  F=THETA(I)
      IF(L.EQ.I)DF=.1D1
      PHI=THETA(K+1)
      S=PHI**PER(I)
      IF(L.NE.K+1)GO TO 220
      DS=PER(I)*PHI**(PER(I)-.1D1)
      DAL=DS*F**(I-T)*S**(I-T-1)
      IF(I.EQ.T)DAL=F
  220 IF(I.LE.T.OR.I.GE.K+1)GO TO 670
      AL=F*S**(I-T)
      IF(L.EQ.I)DAL=S**(I-T)
      GO TO 670
C--------------------------------------------------------------
C    (MOD=3 & 8)        ESTIMATE- MODEL 3
C      PARAMETER SPECIFICATION FOR CONSTANT F,S. EQUIVALENT TO MODEL
C      M3 OF BROWNIE ET AL.
C     AND INTERVAL-MODEL 3: VARIABLE TIME-PERIOD MODEL
C--------------------------------------------------------------
  230 F=THETA(1)
      IF(L.EQ.1)DF=.1D1
      PHI=THETA(2)
      S=PHI**PER(I)
      IF(L.NE.2)GOTO  240
      DS=PER(I)*PHI**(PER(I)-.1D1)
      DAL=DS*F**(I-T)*S**(I-T-1)
      IF(I.EQ.T)DAL=F
  240 IF(I.LE.T.OR.I.GE.K+1)GOTO  670
      AL=F*S**(I-T)
      IF(L.EQ.1)DAL=S**(I-T)
      GO TO 670
  250 IF(MOD.GT.11)GO TO 310
      IF(IAGE.EQ.2)GO TO 260
      GO TO (190,210,230),MOD-8
C**********************************************************************
C      MODEL SPECIFICATION FOR YOUNG IN 2 AGE-CLASS BAND RECOVERY
C      PROBLEM. MODEL HIERARCHY CORRESPONDS TO THAT FOR ADULTS.
C      MODELS 1-3 FOR ADULTS AND YOUNG TOGETHER CORRESPOND TO MODELS
C      H1,H02,AND H01 OF BROWNIE ET AL.
C**********************************************************************
  260 GO TO(270,290,300),MOD-8
C-------------------------------------------------------------
C   (MOD=9)               MODEL BROWNIE:H1
C-------------------------------------------------------------
  270 II=T+K-1+I
      F=THETA(II)
      IF (L .EQ. II) DF=.1D1
      IF(I.GE.T)GO TO 280
      S=THETA(II+T)
      IF (L .EQ. II+T ) DS=.1D1
  280 IF(I.LE.T.OR.I.GE.K+1)GO TO 670
      AL=THETA(II+T-1)
      IF (L.EQ.II+T-1)DAL=.1D1
      GO TO 670
C-------------------------------------------------------------
C   (MOD=10)              MODEL BROWNIE:H01
C-------------------------------------------------------------
  290 II=K+1+I
       FA=THETA(I)
       SA=THETA(K+1)
       F=THETA(II)
       S=THETA(P)
       IF (L .EQ. II) DF=.1D1
       IF (L .EQ. P)DS=.1D1
      IF(I.LE.T.OR.I.GE.K+1)GO TO 670
       AL=FA*S*SA**(I-T)
      IF (L.EQ.I)DAL=S*SA**(I-T)
       IF(L.EQ.K+1)DAL=(I-T)*FA*S*SA**(I-T-1)
       IF(L.EQ.P)DAL=FA*SA**(I-T)
      GO TO 670
C-------------------------------------------------------------
C   (MOD=11)              MODEL BROWNIE:H02
C-------------------------------------------------------------
  300 FA=THETA(1)
      SA=THETA(2)
      F=THETA(3)
      S=THETA(4)
      IF (L .EQ.3) DF=.1D1
      IF (L .EQ. 4) DS=.1D1
      IF(I.LE.T.OR.I.GE.K+1)GO TO 670
      AL=FA*S*SA**(I-T-1)
      IF(L.EQ.1)DAL=S*SA**Z
      IF(L.EQ.2)DAL=FA*S*Z*SA**ZZ
      IF(L.EQ.4)DAL=FA*SA**Z
  310 IF(MOD.GT.18)GO TO 450
      GO TO(330,350,360,380,400,420,430),MOD-11
C------------------------------------------------------
C     MODEL SPECIFICATION FOR MODEL SET TWO-TIME, MODELS 1-7
C     TWO TIME PERIOD SURVIVAL ANALYSIS
C-------------------------------------------------------------
C    (MOD=12)          MODEL-SET TWO-TIME, MODEL 1
C-------------------------------------------------------------
  330 IF(IAGE.EQ.2)GO TO 340
      F=THETA(I)
      S=THETA(T+I)
      IF (L.EQ.I) DF=.1D1
      IF (L.EQ.T+I) DS=.1D1
      GO TO 670
  340 CONTINUE
      IF (I .LT. T) S=THETA(T*2+I)
      IF (L.EQ.T*2+I) DS=.1D1
      GO TO 670
C-------------------------------------------------------------
C   (MOD=13)           MODEL-SET TWO-TIME, MODEL 2
C-------------------------------------------------------------
  350 CONTINUE
      F=THETA(I)
      S=THETA(T+I)
      IF (L.EQ.I) DF=.1D1
      IF (L.EQ.T+I) DS=.1D1
      GO TO 670
C-------------------------------------------------------------
C  (MOD=14)            MODEL-SET TWO-TIME, MODEL 3
C-------------------------------------------------------------
  360 IF(IAGE.EQ.2)GO TO 370
      F=THETA(I)
      IF(L.EQ.I)DF=.1D1
      S=THETA(T+1)
      IF(L.EQ.T+1)DS=.1D1
      GO TO 670
  370 CONTINUE
      IF (I.LT.T)S=THETA(T+1+I)
      IF(L.EQ.T+1+I)DS=.1D1
      GO TO 670
C-------------------------------------------------------------
C   (MOD=15)           MODEL-SET TWO-TIME, MODEL 4
C-------------------------------------------------------------
  380 IF(IAGE.EQ.2)GO TO 390
      F=THETA(I)
      IF(L.EQ.I)DF=.1D1
      S=THETA(T+I)
      IF(L.EQ.T+I)DS=.1D1
      GO TO 670
  390 CONTINUE
      S=THETA(2*T+1)
      IF(L.EQ.2*T+I)DS=.1D1
      GO TO 670
C-------------------------------------------------------------
C  (MOD=16)            MODEL-SET TWO-TIME, MODEL 5
C-------------------------------------------------------------
  400 IF(IAGE.EQ.2)GO TO 410
      F=THETA(I)
      IF(L.EQ.I)DF=.1D1
      S=THETA(T+1)
      IF(L.EQ.T+1)DS=.1D1
      GO TO 670
  410 CONTINUE
      S=THETA(T+2)
      IF(L.EQ.T+2)DS=.1D1
      GO TO 670
C-------------------------------------------------------------
C   (MOD=17)           MODEL-SET TWO-TIME, MODEL 6
C-------------------------------------------------------------
  420 CONTINUE
      F=THETA(I)
      S=THETA(T+1)
      IF(L.EQ.I)DF=.1D1
      IF(L.EQ.T+1)DS=.1D1
      GO TO 670
C-------------------------------------------------------------
C   (MOD=18)           MODEL-SET TWO-TIME, MODEL 7
C-------------------------------------------------------------
  430 IF(IAGE.EQ.2)GO TO 440
      F=THETA(1)
      IF(L.EQ.1)DF=.1D1
      S=THETA(2)
      IF(L.EQ.2)DS=.1D1
      GO TO 670
  440 CONTINUE
      S=THETA(3)
      IF(L.EQ.3) DS=.1D1
      GO TO 670
  450 IF(MOD.GT.24)GO TO 550
C-------------------------------------------------------
C        MODEL SPECIFICATION FOR MODEL SET REW-IND MODELS 1-13
C        REWARD AND CONTROL BAND SURVIVAL ANALYSIS
C------------------------------------------------------
      H=.0D0
      XLAM=.0D0
      S1=.0D0
      S2=.0D0
      DH=.0D0
      DLAM=.0D0
      DS1=.0D0
      DS2=.0D0
      GO TO(470,480,490,500,510,520),MOD-18
C-------------------------------------------------------------
C  (MOD=19)      MODEL-SET REW-IND, MODEL 1
C-------------------------------------------------------------
  470 XLAM=THETA(I)
      IK=2*K+I
      IKK=2*K+T-1+I
      H=THETA(I+K)
      IF(L.EQ.I)DLAM=.1D1
      IF(L.EQ.I+K)DH=.1D1
      IF(I.GE.T)GO TO 530
      S1=THETA(IK)
      S2=THETA(IKK)
      IF(L.EQ.IK)DS1=.1D1
      IF(L.EQ.IKK)DS2=.1D1
      GO TO 530
C-------------------------------------------------------------
C-------------------------------------------------------------
C  (MOD=20)      MODEL-SET REW-IND, MODEL 2
  480 XLAM=THETA(I)
      H=THETA(K+I)
      IF(L.EQ.I)DLAM=.1D1
      IF(L.EQ.T+I)DH=.1D1
      IF(I.GE.T)GO TO 530
      IK=2*K+I
      S1=THETA(IK)
      IF(L.EQ.IK)DS1=.1D1
      S2=S1
      IF(L.EQ.IK)DS2=.1D1
      GO TO 530
C-------------------------------------------------------------
C-------------------------------------------------------------
C  (MOD=21)      MODEL-SET REW-IND, MODEL 3
  490  XLAM=THETA(1)
      H=THETA(I+1)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.I+1)DH=.1D1
      IF(I.GE.T)GO TO 530
      S1=THETA(K+1+I)
      S2=S1
      IF(L.NE.K+I+1)GO TO 530
      DS1=.1D1
      DS2=.1D1
      GO TO 530
C-------------------------------------------------------------
C-------------------------------------------------------------
C  (MOD=22)      MODEL-SET REW-IND, MODEL 4
  500 XLAM=THETA(I)
      H=THETA(K+I)
      KK=2*K+1
      S1=THETA(KK)
      S2=S1
      IF(L.EQ.I)DLAM=.1D1
      IF(L.EQ.K+I)DH=.1D1
      IF(L.NE.KK)GO TO 530
      DS1=.1D1
      DS2=.1D1
      GO TO 530
C-------------------------------------------------------------
C-------------------------------------------------------------
C  (MOD=23)      MODEL-SET REW-IND, MODEL 5
C     CONSTANT LAMBDA,S
  510 XLAM=THETA(1)
      H=THETA(I+1)
      S1=THETA(K+2)
      S2=S1
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.I+1)DH=.1D1
      IF(L.NE.K+2)GO TO 530
      DS1=.1D1
      DS2=.1D1
      GO TO 530
C-------------------------------------------------------------
C-------------------------------------------------------------
C  (MOD=24)      MODEL-SET REW-IND, MODEL 6
C     CONSTANT H,LAMBDA,S
  520 XLAM=THETA(1)
      H=THETA(2)
      S1=THETA(3)
      S2=S1
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.2)DH=.1D1
      IF(L.NE.3)GO TO 530
      DS1=.1D1
      DS2=.1D1
      GO TO 530
C
  530 IF(IAGE.EQ.2)GO TO 540
      F=XLAM*H
      DF=XLAM*DH+DLAM*H
      S=S1
      DS=DS1
      GO TO 670
  540 F=H
      DF=DH
      S=S2
      DS=DS2
      GO TO 670
  550 IF(MOD.GT.31)GO TO 670
C     ------------------------------------------
C     PARAMETER SPECIFICATION FOR MODEL-SET REW-IND, MODELS 7-13
C     SURVIVAL ANALYSIS FOR REWARD AND STANDARD BAND
C     RECOVERIES-- SEPARATION OF HUNTER-REPORTED FROM
C     SOLICITED BAND RECOVERIES
C  -----------------------------------------------
      F=.0D0
      S=.0D0
      DF=.0D0
      DS=.0D0
      H=.0D0
      XLAM=.0D0
      GAMMA=.0D0
      DH=.0D0
      DLAM=.0D0
      DGAMMA=.0D0
      S1=.0D0
      S2=.0D0
      DS1=.0D0
      DS2=.0D0
      KK=K/2
      JJ=J
      IF(J.GT.KK)JJ=J-KK
      GO TO (570,580,590,600,610,620,630),MOD-24
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=25)      MODEL-SET REW-IND, MODEL 7
  570 XLAM=THETA(JJ)
      L1=JJ
      L2=L1+KK
      L3=L1+2*KK
      L4=3*KK+I
      L5=3*KK+T-1+I
      H=THETA(L2)
      GAMMA=THETA(L3)
      IF(L.EQ.L1)DLAM=.1D1
      IF(L.EQ.L2)DH=.1D1
      IF(L.EQ.L3)DGAMMA=.1D1
      IF(I.GE.T)GO TO 640
      S1=THETA(L4)
      S2=THETA(L5)
      IF(L.EQ.L4)DS1=.1D1
      IF(L.EQ.L5) DS2=.1D1
      GO TO 640
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=26)      MODEL-SET REW-IND, MODEL 8
  580 L1=JJ
      L2=JJ+KK
      L3=2*KK+JJ
      L4=3*KK+I
      XLAM=THETA(L1)
      H=THETA(L2)
      GAMMA=THETA(L3)
      IF(L.EQ.L1)DLAM=.1D1
      IF(L.EQ.L2)DH=.1D1
      IF(L.EQ.L3)DGAMMA=.1D1
      IF(I.GE.T)GO TO 640
      S1=THETA(L4)
      S2=S1
      IF(L.EQ.L4)DS1=.1D1
      IF(L.EQ.L4)DS2=.1D1
      GO TO 640
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=27)      MODEL-SET REW-IND, MODEL 9
  590 XLAM=THETA(1)
      L1=JJ+1
      L2=JJ+KK+1
      L3=2*KK+1+I
      H=THETA(L1)
      GAMMA=THETA(L2)
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.L1)DH=.1D1
      IF(L.EQ.L2)DGAMMA=.1D1
      IF(I.GE.T)GO TO 640
      S1=THETA(L3)
      S2=S1
      IF(L.NE.L3)GO TO 640
      DS1=.1D1
      DS2=.1D1
      GO TO 640
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=28)      MODEL-SET REW-IND, MODEL 10
  600 L1=JJ
      L2=JJ+KK
      L3=JJ+2*KK
      L4=3*KK+1
      XLAM=THETA(JJ)
      H=THETA(L2)
      GAMMA=THETA(L3)
      S1=THETA(L4)
      S2=S1
      IF(L.EQ.L1)DLAM=.1D1
      IF(L.EQ.L2)DH=.1D1
      IF(L.EQ.L3)DGAMMA=.1D1
      IF(L.NE.L4)GO TO 640
      DS1=.1D1
      DS2=.1D1
      GO TO 640
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=29)      MODEL-SET REW-IND, MODEL 11
  610 XLAM=THETA(1)
      L1=JJ+1
      L2=JJ+KK+1
      L3=2*KK+2
      H=THETA(L1)
      GAMMA=THETA(L2)
      S1=THETA(L3)
      S2=S1
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.L1)DH=.1D1
      IF(L.EQ.L2)DGAMMA=.1D1
      IF(L.NE.L3)GO TO 640
      DS1=.1D1
      DS2=.1D1
      GO TO 640
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=30)      MODEL-SET REW-IND, MODEL 12
  620 XLAM=THETA(1)
      L1=JJ+1
      L2=KK+2
      L3=KK+3
      H=THETA(L1)
      GAMMA=THETA(L2)
      S1=THETA(L3)
      S2=S1
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.L1)DH=.1D1
      IF(L.EQ.L2)DGAMMA=.1D1
      IF(L.NE.L3)GO TO 640
      DS1=.1D1
      DS2=.1D1
      GO TO 640
C----------------------------------------------------
C----------------------------------------------------
C  (MOD=31)      MODEL-SET REW-IND, MODEL 13
  630 XLAM=THETA(1)
      H=THETA(2)
      GAMMA=THETA(3)
      S1=THETA(4)
      S2=S1
      IF(L.EQ.1)DLAM=.1D1
      IF(L.EQ.2)DH=.1D1
      IF(L.EQ.3)DGAMMA=.1D1
      IF(L.NE.4)GO TO 640
      DS1=.1D1
      DS2=.1D1
      GO TO 640
C
  640 IF(IAGE.EQ.1) GO TO 650
      F=H
      DF=DH
      S=S2
      DS=DS2
      GO TO 670
C
  650 IF(J.GT.KK) GO TO 660
      F=H*XLAM*(.1D1-GAMMA)
      DF=H*XLAM*(-DGAMMA)+(.1D1-GAMMA)*(H*DLAM+XLAM*DH)
      S=S1
      DS=DS1
      GO TO 670
C
  660 F=H*GAMMA
      DF=H*DGAMMA+DH*GAMMA
      S=S1
      DS=DS1
C
  670 RETURN
      END
CCONTROL SEGMENT 'MULT'
      SUBROUTINE HLPMOD
      CHARACTER*2 TMP
      CALL CSCREN
        PRINT 10
   10   FORMAT(31X,'Model description menu'//' Models in MULT ',
     ,  'are divided into 7 model sets.  A model is chosed'/' by ',
     ,  'choosing a model set and a model number. The following is '/
     /  ' a list of available models in MULT:'/)
        PRINT 20
   20   FORMAT(' Model set   model number   parameters'/
     /         ' ESTIMATE         M1        f(i),S(i),alfa(i)'/
     2         '                  M2        f(i),S'/
     3         '                  M3        f,S'/
     4         ' COVAR            C1        f(i),A,B [S(i)=A+Bf(i)]'/
     5         '                  C2        f(i),A,B [S(i)=A+BX(i)]'/
     6         ' INTERVAL         IN1       f(i),PHI(i),alfa(i)'/
     7 18X,'2',9X,'f(i),PHI'/18X,'3',9X,'f,PHI'/
     8         ' BROWNIE          H1        f(i),f''(i),S(i),S''(i),',
     9     'alfa(i),alfa''(i)')
        PRINT 120
  120 FORMAT(  18X,'H02       f(i),f''(i),S,S'' '/
     1         18X,'H01       f,f'',S,S'' '/
     2        /'   where f(i),f''(i) = adlt,yng recv rate in year i'/
     3         '         S(i),S''(i) = adlt,yng surv rate in year i'/
     4         '         alfa(i),alfa''(i) = adlt,yng recv-surv ',
     5         'products in year i'/
     6         9X,'PHI(i) = surv rate in interval i')
      PRINT *,' ** Hit <RETURN> to see more **'
      READ(*,FMT='(A2)')TMP
        PRINT 220
  220   FORMAT(' TWO-TIME         TT1       f(i),PHI(i),GMA(i)'/
     1 18X,'TT2',7X,'f(i),PHI(i)'/18X,'TT3',7X,'f(i),PHI,GMA(i)'/
     2 18X,'TT4',7X,'f(i),PHI(i),GMA'/18X,'TT5',7X,'f(i),PHI,GMA'/
     3 18X,'TT6',7X,'f(i),PHI'/18X,'TT7',7X,'f,PHI,GMA'/
     4        /'   where PHI(i) = 1st period surv rate in year i'/
     5         '         GMA(i) = 2nd period surv rate in year i'/)
      PRINT *,' ** Hit <RETURN> to see more **'
      READ(*,FMT='(A2)')TMP
        PRINT 320
  320   FORMAT(' REW-IND          RI1       LAM(i),H(i),S(i),S''(i)'/
     1 18X,'RI2',7X,'LAM(i),H(i),S(i)'/18X,'RI3',7X,'LAM,H(i),S(i)'/
     2 18X,'RI4',7X,'LAM(i),H(i),S'/18X,'RI5',7X,'LAM,H(i),S'/
     3 18X,'RI6',7X,'LAM,H,S')
        PRINT 330
  330   FORMAT(18X,'RI        LAM(i),H(i),GMA(i),S(i),S''(i)'/
     1 18X,'RI8',7X,'LAM(i),H(i),GMA(i),S(i)'/
     2 18X,'RI9',7X,'LAM,H(i),GMA(i),S(i)'/
     3 18X,'RI10',6X,'LAM(i),H(i),GMA(i),S'/
     4 18X,'RI11',6X,'LAM,H(i),GMA(i),S'/
     4 18X,'RI12',6X,'LAM,H(i),GMA,S'/
     4 18X,'RI13',6X,'LAM,H,GMA,S'/
     4        /'   where LAM(i) = reporting rate in year i'/
     5         '         H(i)   = Harvest rate in year i'/)
      PRINT *,' ** Hit <RETURN> to see more **'
      READ(*,FMT='(A2)')TMP
        PRINT 430
  430   FORMAT(' REW-DIR',10X,'RD1       LAM(i,j),GMA(i,j),H(i,j)'/
     1 18X,'RD2',7X,'LAM(i),GMA(i,j),H(i,j)'/
     2 18X,'RD3',7X,'LAM(j),GMA(i,j),H(i,j)'/
     3 18X,'RD4',7X,'LAM,GMA(i,j),H(i,j)'/
     4 18X,'RD5',7X,'LAM(j),GMA(j),H(i,j)'/
     5 18X,'RD6',7X,'LAM(j),GMA(j),H(j)'/
     6 18X,'RD7',7X,'LAM(j),GMA(j),H(i)'/
     7 18X,'RD8',7X,'LAM(j),GMA,H(i,j)'/
     8 18X,'RD9',7X,'LAM,GMA(j),H(i,j)')
        PRINT 440
  440  FORMAT(18X,'RD10',6X,'LAM,GMA,H(i,j)'/
     2 18X,'RD11',6X,'LAM,GMA,H'/
     3 18X,'RD12',6X,'LAM(j),GMA(j),H'/
     4 18X,'RD13',6X,'LAM(j),GMA,H'/
     5 18X,'RD14',6X,'LAM,GMA(j),H'/
     6 18X,'RD15',6X,'LAM(i),GMA(i),H(i)'/
     7 18X,'RD16',6X,'LAM,GMA(i),H(i)'/18X,'RD17',6X,'LAM(i),H(i)'/
     8 18X,'RD19',6X,'LAM,H'/)
      PRINT *,' ** Hit <RETURN> to continue **'
      READ(*,FMT='(A2)')TMP
      RETURN
      END
CCONTROL SEGMENT 'MULT'
      SUBROUTINE STRTVL(N,S,X,A,B)
      IMPLICIT DOUBLE PRECISION (A-Z)
      INTEGER I,N
      DIMENSION S(30),X(30),A(1),B(1)
      SY=.0D0
      SX=.0D0
      SXSQ=.0D0
      COV=.0D0
      DO 40 I=1,N
         COV=COV+S(I)*X(I)
         SY=SY+S(I)
         SX=SX+X(I)
   40    SXSQ=SXSQ+X(I)*X(I)
      B(1)=(COV-SX*SY/FLOAT(N)) /(SXSQ-SX*SX/FLOAT(N))
      A(1)=(SY-B(1)*SX)/FLOAT(N)
      RETURN
      END
CCONTROL SEGMENT 'MULT'
      SUBROUTINE PMODL(MOD)
      CHARACTER*80 CONSTR(50)
      DATA CONSTR/50*'NONE'/
      CONSTR(2)='S(I)=S - CONSTANT SURVIVAL RATE'
      CONSTR(3)='S(I)=S, F(I)=F - CONSTANT SURVIVAL & RECOVERY RATE'
      CONSTR(4)='S(I)=A + B*F(I)'
      CONSTR(5)='S(I)=A + B*X(I) : X(I)=COVARIATE VARIABLE IN YEAR I'
      CONSTR(6)='Q(I)=S(I)**D(I)'
      CONSTR(7)='Q(I)=S**D(I) : CONSTANT SURVIVAL PER UNIT TIME'
      CONSTR(8)='Q(I)=S**D(I),F(I)=F:CONSTANT SURV & RECV PER UNIT TIME'
      CONSTR(10)='S(I)=S,S''(I)=S'':CONSTANT ADLT & YOUNG SURVIVAL'
      CONSTR(11)='S(I)=S,S''(I)=S'',F(I)=F,F''(I)=F'' '
      CONSTR(13)='S(I)=Q(I) : SPRING SURV = FALL SURV'
      CONSTR(14)='Q(I)=Q : CONSTANT SPRING SURVIVAL RATE'
      CONSTR(15)='S(I)=S : CONSTANT FALL SURVIVAL RATE'
      CONSTR(16)='Q(I)=Q, S(I)=S : CONSTANT SPRING & FALL SURVIVAL'
      CONSTR(17)='Q(I)=S(I)=S : CONSTANT & EQUAL SPRING AND SUMMER SURVI
     IVAL RATES'
      CONSTR(18)='F(I)=F,Q(I)=Q,S(I)=S : CONSTANT RECV & SURV RATES'
      CONSTR(20)='S(I)=S''(I) : CONTROL SURV = REWARD SURV RATE'
      CONSTR(21)='L(I)=L,S(I)=S''(I):CONST REPORTING RATE,EQ SURV RATES'
      CONSTR(22)='S(I)=S''(I)=S: CONSTANT SURVIVAL RATES'
      CONSTR(23)='L(I)=L,S(I)=S''(I)=S:CONST SURV & REPORTING RATES'
      CONSTR(24)='L(I)=L,H(I)=H,S(I)=S''(I)=S:CONST REP,HARV,SURV RATES'
      CONSTR(26)='S(I)=S''(I):CONTROL & REWARD SURVIVAL RATES EQUAL'
      CONSTR(27)=CONSTR(21)
      CONSTR(28)=CONSTR(22)
      CONSTR(29)=CONSTR(23)
      CONSTR(30)='L(I)=L,G(I)=G,S(I)=S''(I)=S:CONST REP,SOL,SURV RATES'
      CONSTR(31)='L(I)=L,H(I)=H,G(I)=G,S(I)=S''(I)=S:CONST REP,HARV,SOL,
     ,SURV RATES'
      CONSTR(33)='L(I,J)=L(I)'
      CONSTR(34)='L(I,J)=L(J)'
      CONSTR(35)='L(I,J)=L'
      CONSTR(36)='L(I,J)=L(J),G(I,J)=G(J)'
      CONSTR(37)='L(I,J)=L(J),G(I,J)=G(J),H(I,J)=H(J)'
      CONSTR(38)='L(I,J)=L(J),G(I,J)=G(J),H(I,J)=H(I)'
      CONSTR(39)='L(I,J)=L(J),G(I,J)=G'
      CONSTR(40)='L(I,J)=L,G(I,J)=G(J)'
      CONSTR(41)='L(I,J)=L,G(I,J)=G'
      CONSTR(42)='L(I,J)=L,G(I,J)=G,H(I,J)=H'
      CONSTR(43)='L(I,J)=L(J),G(I,J)=G(J),H(I,J)=H'
      CONSTR(44)='L(I,J)=L(J),G(I,J)=G,H(I,J)=H'
      CONSTR(45)='L(I,J)=L,G(I,J)=G,H(I,J)=H'
      CONSTR(46)='L(I,J)=L(I),G(I,J)=G(I),H(I,J)=H(I)'
      CONSTR(47)='L(I,J)=L,G(I,J)=G(I),H(I,J)=H(I)'
      CONSTR(48)='L(I,J)=L(I),H(I,J)=H(I)'
      CONSTR(49)='L(I,J)=L,H(I,J)=H(I)'
      CONSTR(50)='L(I,J)=L,H(I,J)=H'
      IF(MOD.LE.0)THEN
        WRITE(1,30)
        WRITE(1,31)
        WRITE(1,32)
        WRITE(1,33)
       ELSEIF(MOD.LE.3)THEN
        WRITE(1,41)
       ELSEIF(MOD.LE.5)THEN
        WRITE(1,41)
       ELSEIF(MOD.LE.8)THEN
        WRITE(1,42)
       ELSEIF(MOD.LE.11)THEN
        WRITE(1,44)
       ELSEIF(MOD.LE.18)THEN
        WRITE(1,45)
       ELSEIF(MOD.LE.24)THEN
        WRITE(1,46)
       ELSEIF(MOD.LE.31)THEN
        WRITE(1,47)
      ELSE
        WRITE(1,47)
      ENDIF
      IF(MOD.GT.0)WRITE(1,10)CONSTR(MOD)
   10 FORMAT(/' CONSTRAINTS:',A80/)
   30 FORMAT(/' DEFINITIONS:'/1X,12('-')/
     1/' S(I) = SURVIVAL RATE FROM YEAR I TO I+1'//
     2' F(I) = RECOVERY RATE IN YEAR I'//' Q(I) = SURVIVAL RATE FOR INTE
     3RVAL I IN INTERVAL MODELS (PHI IN MULT MS)'//
     4' Q(I) = SPRING TO FALL SURVIVAL RATE IN TWO-TIME PERIOD MODELS (P
     5HI IN MULT MS)'/)
   31 FORMAT(' G(I) = FALL TO SPRING SURVIVAL RATE OR BAND SOLICITATION
     6RATE (GAMMA IN MULT MS)'//' L(I) = REPORTING RATE IN YEAR I (LAMBD
     7A IN MULT MS)'//' H(I) = HARVEST RATE IN YEAR I = F(I) / L(I)'//
     8' D(I) = INTERVAL LENGTH BETWEEN  TIME I AND I+1'/)
   32 FORMAT(' a(I) = PRODUCT  OF F(I) AND S(I) WHEN THE NUMBER OF YEARS
     1 OF RECOVERY IS GREATER THAN THE NUMBER OF YEARS OF BANDING'//
     2' A(1) = INTERCEPT IN LINEAR COVARIATE MODELS (C1,C2)'/
     3/' B(1) = SLOPE IN LINEAR COVARIATE MODELS'/)
   33 FORMAT(1X,130('-')/                               ' ** NOTE: VARIA
     1BLES WITH A TRAILING QUOTE (EG. S'',F'') SIGNIFY PARAMETERS WHICH
     2APPLY TO YOUNG OR REWARD BANDED BIRDS.'//10X,'VARIABLES WITHOUT A
     3SUBSCRIPT DENOTE PARAMETERS WHICH ARE CONSTANT OVER TIME.'/
     4 1X,130('-'))
   41 FORMAT(/' ONE AGE CLASS MODEL- STRUCTURE IS AS FOLLOWS:'//
     / '  NUMBER   ---------- RECOVERED IN -----------'/
     / '  BANDED   YEAR1   YEAR2   YEAR3     YEAR4'//
     / '    N1     N1F1    N1F2S1  N1F3S1S2  N1F4S1S2S3'/
     / '    N2             N2F2    N2F3S2    N2F4S2S3')
   42 FORMAT(/' ONE AGE CLASS MODEL- STRUCTURE IS AS FOLLOWS:'//
     / '  NUMBER   ---------- RECOVERED IN -----------'/
     / '  BANDED   YEAR1   YEAR2   YEAR3     YEAR4'//
     / '    N1     N1F1    N1F2Q1  N1F3Q1Q2  N1F4Q1Q2Q3'/
     / '    N2             N2F2    N2F3Q2    N2F4Q2Q3')
   44 FORMAT(/' TWO AGE CLASS MODEL- STRUCTURE IS AS FOLLOWS:'//
     /16X,'BANDED AS ADULTS',39X,'BANDED AS YOUNG'/
     / 2('  NUMBER   ---------- RECOVERED IN -----------',9X)/
     / 2('  BANDED   YEAR1   YEAR2     YEAR3       YEAR4',9X)//
     /   '    N1     N1F1    N1F2S1    N1F3S1S2    N1F4S1S2S3',
     , 8X, 50HM1     M1F1'   M1F2'S1'  M1F3'S1'S2  M1F4'S1'S2S3 /
     /   '    N2             N2F2      N2F3S2      N2F4S2S3',
     , 10X,47HM2             M2F2'     M2F3'S2'    M2F4'S2'S3)
   45 FORMAT(/' TWO-TIME PERIOD MODEL- STRUCTURE IS AS FOLLOWS:'//
     /16X,'BANDED IN SPRING',39X,'BANDED IN FALL'/
     / 2('  NUMBER   ---------- RECOVERED IN -----------',9X)/
     / 2('  BANDED   YEAR1   YEAR2     YEAR3       YEAR4',9X)//
     /   '    N1     N1Q1F1  N1F2Q1S1  N1F3Q1S1S2  N1F4S1S2S3',
     , 8X, 'M1     M1F1    M1F2S1    M1F3S1S2    M1F4S1S2S3'/
     /   '    N2             N2F2      N2F3S2      N2F4S2S3',
     , 10X,'M2             M2F2      M2F3S2      M2F4S2S3')
   46 FORMAT(/' REWARD BAND MODEL(NO SOLICITED RECOVERIES)-STRUCTURE:'//
     /15X,'CONTROL',51X,'REWARD'/
     / 2('  NUMBER   ---------- RECOVERED IN -----------',9X)/
     / 2('  BANDED   YEAR1   YEAR2     YEAR3       YEAR4',9X)//
     /   '    N1     N1F1    N1F2S1    N1F3S1S2    N1F4S1S2S3',
     , 8X, 50HM1     M1H1    M1H2S1'   M1H3S1'S1'  M1H4S1'S2'S3'/
     /   '    N2             N2F2      N2F3S2      N2F4S2S3',
     , 10X,47HM2             M2H2      M2H3S2'     M2H4S2'S3')
   47 FORMAT(/' REWARD BAND MODEL(W/ SOLICITED RECOVERIES)-STRUCTURE:'//
     /8X,'CONTROL:HUNTER REPORTED',20X,'CONTROL:SOLICITED',32X,'REWARD'
     //3('  NUMBER   ------- RECOVERED IN --------',3X)/
     / 3('  BANDED    AREA 1        AREA 2  ',9X)//
     /   '    N1   L11(1-G11)H11  L12(1-G12)H12',
     ,   '          N1      L11H11          L12H12',
     , 15X,'N''1',6X,'N''1H11',8X,'N''1H12'/
     /   '    N2   L21(1-G21)H21  L22(1-G22)H22',
     /   '          N2      L21H21          L22H22',
     , 15X,'N''2',6X,'N''1H21',8X,'N''1H22'/)
      RETURN
      END
CCONTROL SEGMENT 'MULT'
      SUBROUTINE CSCREN
C         subroutine to clear the crt screen
C  Televideo 920,925: send cntl-z to screen
C     PRINT *,CHAR(26)
      RETURN
      END
